@@ -1,9 +1,9 @@
 /*
- * $Id: alert.h,v 1.16 2003/05/20 17:35:26 we7u Exp $
+ * $Id: alert.h,v 1.19 2004/07/19 21:17:18 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2004  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -41,6 +41,11 @@
 #include "db.h"
 #include "maps.h"
 
+
+// How many alerts we add storage for each time we're short.
+#define ALERT_COUNT_INCREMENT 200
+
+
 typedef enum {
     ALERT_TITLE,
     ALERT_TAG,
@@ -49,7 +54,7 @@ typedef enum {
 } alert_match_level;
 
 #define ALERT_ALL ALERT_FROM
-
+enum flag_list {on_screen, source, max_flag=16};
 
 typedef struct {
     double top_boundary, left_boundary, bottom_boundary, right_boundary;
@@ -64,7 +69,7 @@ typedef struct {
        0 - on screen
        1 - source
     */
-    char flags[16];
+    char flags[max_flag];
     char filename[64];
     int  index;         // Index into shapefile
     char seq[10];
@@ -80,6 +85,7 @@ extern alert_entry *alert_list;
 extern int alert_max_count;
 
 extern void alert_print_list(void);
+extern void alert_sort_active(void);
 extern int alert_active(alert_entry *alert, alert_match_level match_level);
 extern int alert_display_request(void);
 extern int alert_on_screen(void);
