@@ -1,9 +1,9 @@
 /*
- * $Id: bulletin_gui.c,v 1.18 2003/05/20 17:34:10 we7u Exp $
+ * $Id: bulletin_gui.c,v 1.27 2004/10/18 18:57:54 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2004  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -66,7 +66,6 @@
 #include "xastir.h"
 #include "main.h"
 #include "bulletin_gui.h"
-#include "db.h"
 #include "interface.h"
 #include "util.h"
 
@@ -128,6 +127,9 @@ void bulletin_message(char *call_sign, char *tag, char *packet_message, time_t s
     struct tm *tmp;
     time_t timehd;
     char time_str[20];
+    char *temp_ptr;
+
+
     timehd=sec_heard;
     tmp = localtime(&timehd);
 
@@ -142,7 +144,7 @@ void bulletin_message(char *call_sign, char *tag, char *packet_message, time_t s
     distance = distance_from_my_station(call_sign,temp_my_course);
     xastir_snprintf(temp, sizeof(temp), "%-9s:%-4s (%s %6.1f %s) %s\n",
             call_sign, &tag[3], time_str, distance,
-            units_english_metric ? langcode("UNIOP00004"): langcode("UNIOP00005"),
+            english_units ? langcode("UNIOP00004"): langcode("UNIOP00005"),
             packet_message);
 
 // Operands of <= have incompatible types (double, int):
@@ -153,7 +155,12 @@ void bulletin_message(char *call_sign, char *tag, char *packet_message, time_t s
 begin_critical_section(&display_bulletins_dialog_lock, "bulletin_gui.c:bulletin_message" );
 
         if ((Display_bulletins_dialog != NULL)) {   // Dialog is up
-            strncpy(temp_text, temp, 14);
+
+            xastir_snprintf(temp_text,
+                sizeof(temp_text),
+                "%s",
+                temp);
+
             temp_text[14] = '\0';
 
             // Look for this bulletin ID.  "pos" will hold the first char position if found.
@@ -178,7 +185,9 @@ begin_critical_section(&display_bulletins_dialog_lock, "bulletin_gui.c:bulletin_
                 }
                 XmTextInsert(Display_bulletins_text,pos,temp);
             }
-            bulletin_range = atoi(XmTextFieldGetString(dist_data));
+            temp_ptr = XmTextFieldGetString(dist_data);
+            bulletin_range = atoi(temp_ptr);
+            XtFree(temp_ptr);
         }
 
 end_critical_section(&display_bulletins_dialog_lock, "bulletin_gui.c:bulletin_message" );
@@ -421,19 +430,21 @@ static void find_zero_position_bulletins(void) {
 // posit for it might come in as well).  If so, checks for bulletins
 // that are newer than first_new_bulletin_time and fit within our
 // range.  If any found, it updates the Bulletins dialog.
-time_t last_bulletin_check = 0;
+time_t last_bulletin_check = (time_t)0l;
 void check_for_new_bulletins() {
 
 
-    // Check every two seconds max
-    if ( (last_bulletin_check + 2) > sec_now() ) {
+    // Check every 15 seconds max
+    if ( (last_bulletin_check + 15) > sec_now() ) {
         return;
     }
+    last_bulletin_check = sec_now();
 
     // Look first to see if we might be able to fill in positions on
     // any older bulletins, then cause a popup for those that fit
     // our parameters.  The below function sets new_bulletin_flag if
     // it is able to fill in a distance for an older bulletin.
+// Note:  This is time-consuming!
     find_zero_position_bulletins();
 
     // Any new bulletins to check?  If not, return
@@ -441,8 +452,6 @@ void check_for_new_bulletins() {
         return;
     }
 
-    last_bulletin_check = sec_now();
-
     // Enough time passed since most recent bulletin?  Need to have
     // enough time to perhaps fill in a distance for each bulletin.
     if ( (last_new_bulletin_time + 15) > sec_now() ) {
@@ -487,9 +496,13 @@ void check_for_new_bulletins() {
 
 void Display_bulletins_destroy_shell(/*@unused@*/ Widget widget, XtPointer clientData, /*@unused@*/ XtPointer callData) {
     Widget shell = (Widget) clientData;
+    char *temp_ptr;
+
 
     // Keep this.  It stores the range in a global variable when we destroy the dialog.
-    bulletin_range = atoi(XmTextFieldGetString(dist_data));
+    temp_ptr = XmTextFieldGetString(dist_data);
+    bulletin_range = atoi(temp_ptr);
+    XtFree(temp_ptr);
 
     XtPopdown(shell);
 
@@ -507,9 +520,13 @@ end_critical_section(&display_bulletins_dialog_lock, "bulletin_gui.c:Display_bul
 
 
 void Display_bulletins_change_range(/*@unused@*/ Widget widget, /*@unused@*/ XtPointer clientData, /*@unused@*/ XtPointer callData) {
+    char *temp_ptr;
+
 
     // Keep this.  It stores the range in a global variable when we destroy the dialog.
-    bulletin_range = atoi(XmTextFieldGetString(dist_data));
+    temp_ptr = XmTextFieldGetString(dist_data);
+    bulletin_range = atoi(temp_ptr);
+    XtFree(temp_ptr);
 
     view_zero_distance_bulletins = (int)XmToggleButtonGetState(zero_bulletin_data);
     //fprintf(stderr,"%d\n",view_zero_distance_bulletins);
@@ -611,7 +628,7 @@ begin_critical_section(&display_bulletins_dialog_lock, "bulletin_gui.c:Bulletins
                 XmNnavigationType, XmTAB_GROUP,
                 NULL);
 
-        dist_units = XtVaCreateManagedWidget((units_english_metric?langcode("UNIOP00004"):langcode("UNIOP00005")),
+        dist_units = XtVaCreateManagedWidget((english_units?langcode("UNIOP00004"):langcode("UNIOP00005")),
                 xmLabelWidgetClass, 
                 form,
                 XmNtopAttachment, XmATTACH_FORM,
@@ -673,7 +690,8 @@ begin_critical_section(&display_bulletins_dialog_lock, "bulletin_gui.c:Bulletins
         XtSetArg(args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
         XtSetArg(args[n], XmNtopWidget, dist); n++;
         XtSetArg(args[n], XmNtopOffset, 20); n++;
-        XtSetArg(args[n], XmNbottomAttachment, XmATTACH_NONE); n++;
+        XtSetArg(args[n], XmNbottomAttachment, XmATTACH_FORM); n++;
+        XtSetArg(args[n], XmNbottomOffset, 30); n++;
         XtSetArg(args[n], XmNleftAttachment, XmATTACH_FORM); n++;
         XtSetArg(args[n], XmNleftOffset, 5); n++;
         XtSetArg(args[n], XmNrightAttachment, XmATTACH_FORM); n++;
@@ -690,9 +708,7 @@ begin_critical_section(&display_bulletins_dialog_lock, "bulletin_gui.c:Bulletins
         button_close = XtVaCreateManagedWidget(langcode("UNIOP00003"),
                 xmPushButtonGadgetClass, 
                 form,
-                XmNtopAttachment, XmATTACH_WIDGET,
-                XmNtopWidget, XtParent(Display_bulletins_text),
-                XmNtopOffset, 2,
+                XmNtopAttachment, XmATTACH_NONE,
                 XmNbottomAttachment, XmATTACH_FORM,
                 XmNbottomOffset, 5,
                 XmNleftAttachment, XmATTACH_POSITION,
@@ -721,8 +737,6 @@ begin_critical_section(&display_bulletins_dialog_lock, "bulletin_gui.c:Bulletins
 
         redraw_on_new_packet_data=1;
         XtPopup(Display_bulletins_dialog,XtGrabNone);
-        fix_dialog_vsize(Display_bulletins_dialog);
-
 
 end_critical_section(&display_bulletins_dialog_lock, "bulletin_gui.c:Bulletins" );
 
