@@ -1,9 +1,9 @@
 /*
- * $Id: fcc_data.c,v 1.5 2003/05/20 17:34:10 we7u Exp $
+ * $Id: fcc_data.c,v 1.11 2004/09/17 19:56:56 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2004  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -43,10 +43,10 @@
 
 #include <Xm/XmAll.h>
 
+#include "xastir.h"
 #include "fcc_data.h"
 #include "xa_config.h"
 #include "main.h"
-#include "xastir.h"
 
 
 
@@ -89,9 +89,9 @@ int build_fcc_index(int type){
     int found,i,num;
 
     if (type==1)
-        strcpy(database_name,"fcc/appl.dat");
+        xastir_snprintf(database_name, sizeof(database_name), "fcc/appl.dat");
     else
-        strcpy(database_name,"fcc/EN.dat");
+        xastir_snprintf(database_name, sizeof(database_name), "fcc/EN.dat");
 
     /* ====================================================================    */
     /*    If the index file is there, exit                */
@@ -128,7 +128,7 @@ int build_fcc_index(int type){
     /*    write out the current callsign and RBA of the db file         */
     /*    skip (index_skip) records and do it again until no more        */
     /*                                    */
-    strncpy (fccdata," ",sizeof(fccdata));
+    xastir_snprintf(fccdata,sizeof(fccdata)," ");
     while(!feof(fdb)) {
         call_offset = (unsigned long)ftell(fdb);
         (void)fgets(fccdata, (int)sizeof(fccdata), fdb);
@@ -234,28 +234,31 @@ int search_fcc_data_appl(char *callsign, FccAppl *data) {
     char char_offset[16];
     char index[32];
 
-    strcpy(data->id_file_num,"");
-    strcpy(data->type_purpose,"");
+    data->id_file_num[0] = '\0';
+    data->type_purpose[0] = '\0';
     data->type_applicant=' ';
-    strcpy(data->name_licensee,"");
-    strcpy(data->text_street,"");
-    strcpy(data->text_pobox,"");
-    strcpy(data->city,"");
-    strcpy(data->state,"");
-    strcpy(data->zipcode,"");
-    strcpy(data->date_issue,"");
-    strcpy(data->date_expire,"");
-    strcpy(data->date_last_change,"");
-    strcpy(data->id_examiner,"");
+    data->name_licensee[0] = '\0';
+    data->text_street[0] = '\0';
+    data->text_pobox[0] = '\0';
+    data->city[0] = '\0';
+    data->state[0] = '\0';
+    data->zipcode[0] = '\0';
+    data->date_issue[0] = '\0';
+    data->date_expire[0] = '\0';
+    data->date_last_change[0] = '\0';
+    data->id_examiner[0] = '\0';
     data->renewal_notice=' ';
-    strcpy(temp,callsign);
+    xastir_snprintf(temp,
+        sizeof(temp),
+        "%s",
+        callsign);
     (void)call_only(temp);
 
     xastir_snprintf(calltemp, sizeof(calltemp), "%-6.6s", temp);
 // calltemp doesn't appear to get used anywhere...
 
     /* add end of field data */
-    strcat(temp,"|");
+    strncat(temp, "|", sizeof(temp) - strlen(temp));
     len=(int)strlen(temp);
     found=0;
     line_pos=0;
@@ -275,13 +278,13 @@ int search_fcc_data_appl(char *callsign, FccAppl *data) {
     fndx=fopen(get_user_base_dir("data/appl.ndx"),"r");
     if (fndx!=NULL){
         (void)fgets(index,(int)sizeof(index),fndx);
-        strncpy(char_offset,&index[6],16);
+        xastir_snprintf(char_offset,sizeof(char_offset),"%s",&index[6]);
 
         // Search through the indexes looking for a callsign which is
         // close to the callsign of interest.  If callsign is later in
         // the alphabet than the current index, snag the next index.
         while (!feof(fndx) && strncmp(callsign,index,6) > 0) {
-            strncpy(char_offset,&index[6],16);
+            xastir_snprintf(char_offset,sizeof(char_offset),"%s",&index[6]);
             (void)fgets(index,(int)sizeof(index),fndx);
         }
     } else {
@@ -316,7 +319,7 @@ int search_fcc_data_appl(char *callsign, FccAppl *data) {
             if (bytes_read>0) {
                 for (xx=0;(xx<bytes_read) && !found;xx++) {
                     if(data_in[xx]!='\n' && data_in[xx]!='\r') {
-                        if (line_pos<200) {
+                        if (line_pos<199) {
                             line[line_pos++]=data_in[xx];
                             line[line_pos]='\0';
                         }
@@ -358,11 +361,11 @@ int search_fcc_data_appl(char *callsign, FccAppl *data) {
                                         case(1):
                                             switch(i) {
                                                 case(0):
-                                                    strcpy(data->id_file_num,line+pos_it);
+                                                    xastir_snprintf(data->id_file_num,sizeof(data->id_file_num),"%s",line+pos_it);
                                                     break;
 
                                                 case(1):
-                                                    strcpy(data->type_purpose,line+pos_it);
+                                                    xastir_snprintf(data->type_purpose,sizeof(data->type_purpose),"%s",line+pos_it);
                                                     break;
 
                                                 case(2):
@@ -370,43 +373,43 @@ int search_fcc_data_appl(char *callsign, FccAppl *data) {
                                                     break;
 
                                                 case(3):
-                                                    strcpy(data->name_licensee,line+pos_it);
+                                                    xastir_snprintf(data->name_licensee,sizeof(data->name_licensee),"%s",line+pos_it);
                                                     break;
 
                                                 case(4):
-                                                    strcpy(data->text_street,line+pos_it);
+                                                    xastir_snprintf(data->text_street,sizeof(data->text_street),"%s",line+pos_it);
                                                     break;
 
                                                 case(5):
-                                                    strcpy(data->text_pobox,line+pos_it);
+                                                    xastir_snprintf(data->text_pobox,sizeof(data->text_pobox),"%s",line+pos_it);
                                                     break;
 
                                                 case(6):
-                                                    strcpy(data->city,line+pos_it);
+                                                    xastir_snprintf(data->city,sizeof(data->city),"%s",line+pos_it);
                                                     break;
 
                                                 case(7):
-                                                    strcpy(data->state,line+pos_it);
+                                                    xastir_snprintf(data->state,sizeof(data->state),"%s",line+pos_it);
                                                     break;
 
                                                 case(8):
-                                                    strcpy(data->zipcode,line+pos_it);
+                                                    xastir_snprintf(data->zipcode,sizeof(data->zipcode),"%s",line+pos_it);
                                                     break;
 
                                                 case(9):
-                                                    strcpy(data->date_issue,line+pos_it);
+                                                    xastir_snprintf(data->date_issue,sizeof(data->date_issue),"%s",line+pos_it);
                                                     break;
 
                                                 case(11):
-                                                    strcpy(data->date_expire,line+pos_it);
+                                                    xastir_snprintf(data->date_expire,sizeof(data->date_expire),"%s",line+pos_it);
                                                     break;
 
                                                 case(12):
-                                                    strcpy(data->date_last_change,line+pos_it);
+                                                    xastir_snprintf(data->date_last_change,sizeof(data->date_last_change),"%s",line+pos_it);
                                                     break;
 
                                                 case(13):
-                                                    strcpy(data->id_examiner,line+pos_it);
+                                                    xastir_snprintf(data->id_examiner,sizeof(data->id_examiner),"%s",line+pos_it);
                                                     break;
 
                                                 case(14):
@@ -421,27 +424,27 @@ int search_fcc_data_appl(char *callsign, FccAppl *data) {
                                         case(2):
                                             switch (i) {
                                                 case(0):
-                                                    strcpy(data->id_file_num,line+pos_it);
+                                                    xastir_snprintf(data->id_file_num,sizeof(data->id_file_num),"%s",line+pos_it);
                                                     break;
 
                                                 case(2):
-                                                    strcpy(data->name_licensee,line+pos_it);
+                                                    xastir_snprintf(data->name_licensee,sizeof(data->name_licensee),"%s",line+pos_it);
                                                     break;
 
                                                 case(10):
-                                                    strcpy(data->text_street,line+pos_it);
+                                                    xastir_snprintf(data->text_street,sizeof(data->text_street),"%s",line+pos_it);
                                                     break;
 
                                                 case(11):
-                                                    strcpy(data->city,line+pos_it);
+                                                    xastir_snprintf(data->city,sizeof(data->city),"%s",line+pos_it);
                                                     break;
 
                                                 case(12):
-                                                    strcpy(data->state,line+pos_it);
+                                                    xastir_snprintf(data->state,sizeof(data->state),"%s",line+pos_it);
                                                     break;
 
                                                 case(13):
-                                                    strcpy(data->zipcode,line+pos_it);
+                                                    xastir_snprintf(data->zipcode,sizeof(data->zipcode),"%s",line+pos_it);
                                                     break;
 
                                                 default:
@@ -460,7 +463,7 @@ int search_fcc_data_appl(char *callsign, FccAppl *data) {
                             // location for the callsign.  Return if so.
                             if ( (temp[0] < line[pos]) ||
                                     ( (temp[0] == line[pos]) && (temp[1] < line[pos+1]) ) ) {
-                                popup_message("Callsign Search", "Callsign Not Found!");
+                                popup_message_always("Callsign Search", "Callsign Not Found!");
                                 //fprintf(stderr,"%c%c\t%c%c\n",temp[0],temp[1],line[pos],line[pos+1]);
                                 (void)fclose(f);
                                 return(0);
