@@ -1,6 +1,8 @@
 // Modification for Xastir CVS purposes
 //
-// $Id: festival.c,v 1.9 2003/04/12 01:32:42 we7u Exp $
+// Portions Copyright (C) 2000-2004  The Xastir Group
+//
+// $Id: festival.c,v 1.13 2004/09/07 15:39:52 we7u Exp $
 //
 // End of modification
 
@@ -76,6 +78,7 @@
 /*                  N7IPB    04/08/2001                                  */
 /*                                                                       */
 /*=======================================================================*/
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -86,11 +89,14 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <fcntl.h>
-#include "festival.h"
 #include <errno.h>
+
+
 #include "xastir.h"
+#include "festival.h"
 #include "snprintf.h"
 
+
 FT_Info *info = NULL;
 
 static char last_speech_text[8000];
@@ -227,6 +233,7 @@ int festivalOpen(void) {
     // Check whether we already have a socket open (or think we do)
     if (info->server_fd != -1) {    // We have a socket open
         (void)festivalClose();      // Close it, free struct
+        usleep(50000);              // 50ms wait
     }
 
     info->server_fd = festival_socket_open(info->server_host, info->server_port);
@@ -234,6 +241,7 @@ int festivalOpen(void) {
     if (info->server_fd == -1) {    // Error occured opening socket
         //fprintf(stderr,"festivalOpen: Error opening socket\n");
         (void)festivalClose();      // Close, free struct
+        usleep(50000);              // 50ms wait
         return(-1);
     }
 
@@ -415,9 +423,12 @@ int SayText(char *text) {
     if ( (strcmp(last_speech_text,text) == 0) // Strings match
             && (last_speech_time + 30 > sec_now()) ) {
 
-    //fprintf(stderr,"Same text, skipping speech: %d seconds, %s\n",
-    //    (int)(sec_now() - last_speech_time),
-    //    text);
+/*
+    fprintf(stderr,
+        "Same text, skipping speech: %d seconds, %s\n",
+        (int)(sec_now() - last_speech_time),
+        text);
+*/
 
         return(1);
     }
@@ -431,6 +442,7 @@ int SayText(char *text) {
     last_speech_time = sec_now();
 
     festivalStringToSpeech(text);
+
     return(0);
 }
 
