@@ -1,9 +1,9 @@
 /*
- * $Id: hostname.c,v 1.8 2003/03/20 22:29:19 jtwilley Exp $
+ * $Id: hostname.c,v 1.16 2004/10/03 04:58:02 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2004  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -89,7 +89,7 @@ static void host_time_out( /*@unused@*/ int sig) {
 /* TIMEOUT for time exceeded                                             */
 /*************************************************************************/
 
-char *host_lookup(char *host, char *ip, int time) {
+char *host_lookup(char *host, char *ip, int ip_size, int time) {
     /*struct sockaddr_in address;*/
     char **names, **addrs;
     static struct hostent *hostinfo;
@@ -105,7 +105,7 @@ char *host_lookup(char *host, char *ip, int time) {
     char ip_addr[400];
     char temp[40];
     int fp[2];
-    char buf[401];
+    char buf[400];
     int ip_found;
     int first;
     int tm;
@@ -137,6 +137,18 @@ char *host_lookup(char *host, char *ip, int time) {
 //---------------------------------------------------------------------------------------
             if (host_pid==0) {  // We're in the child process
 
+
+                // Change the name of the new child process.  So far
+                // this only works for "ps" listings, not for "top".
+                // This code only works on Linux.  For BSD use
+                // setproctitle(3), NetBSD can use setprogname(2).
+#ifdef __linux__
+                init_set_proc_title(my_argc, my_argv, my_envp);
+                set_proc_title("%s", "hostname lookup (xastir)");
+                //printf("DEBUG: %s\n", Argv[0]);
+#endif  // __linux__
+
+
                 // Close the end of the pipe we don't need here
 
                 if (debug_level & 1024)
@@ -159,14 +171,14 @@ char *host_lookup(char *host, char *ip, int time) {
                     (void)signal(SIGALRM, previous_loc);
 
                     // Return net connection time out
-                    strcpy(ip_addr,"TIMEOUT");
+                    xastir_snprintf(ip_addr, sizeof(ip_addr), "TIMEOUT");
                     (void)write(fp[1],ip_addr,strlen(ip_addr));
 
                     if (debug_level & 1024)
                         fprintf(stderr,"Child closing write end of pipe\n");
 
                     close(fp[1]);   // All done writing to the pipe
-                    exit(EXIT_FAILURE);
+                    exit(EXIT_FAILURE); // Exit from child process
                 }
                 (void)alarm(time);  // Start the timer
 
@@ -180,7 +192,7 @@ char *host_lookup(char *host, char *ip, int time) {
                 // Turn off the alarm
                 (void)alarm(0);
                 // Reset the SIGALRM handler to its previous value
-                (void)signal(SIGALRM,previous_loc);
+                (void)signal(SIGALRM, previous_loc);
 
                 if (hostinfo) {
                     names = hostinfo -> h_aliases;
@@ -206,10 +218,17 @@ char *host_lookup(char *host, char *ip, int time) {
                                 if (strlen(temp)>7) {
                                     /* IP found */
                                     if((strlen(ip_addr)+strlen(temp))<sizeof(ip_addr)) {
-                                        if (ips>0)
-                                            strcat(ip_addr," ");
 
-                                        strcat(ip_addr,temp);
+                                        if (ips>0) {
+                                            strncat(ip_addr,
+                                                " ",
+                                                sizeof(ip_addr) - strlen(ip_addr));
+                                        }
+
+                                        strncat(ip_addr,
+                                            temp,
+                                            sizeof(ip_addr) - strlen(ip_addr));
+
                                         ips++;
                                     }
                                 }
@@ -224,7 +243,7 @@ char *host_lookup(char *host, char *ip, int time) {
                     }
                     if (ip_found==0) {
                         /* Host not found */
-                        strcpy(ip_addr,"NOIP");
+                        xastir_snprintf(ip_addr, sizeof(ip_addr), "NOIP");
 
                         if (debug_level & 1024)
                             fprintf(stderr,"Host NO IP");
@@ -233,7 +252,7 @@ char *host_lookup(char *host, char *ip, int time) {
                 }
                 else {
                     /* Host not found */
-                    strcpy(ip_addr,"NOHOST");
+                    xastir_snprintf(ip_addr, sizeof(ip_addr), "NOHOST");
 
                     if (debug_level & 1024)
                         fprintf(stderr,"NO HOST\n");
@@ -251,7 +270,7 @@ char *host_lookup(char *host, char *ip, int time) {
                     fprintf(stderr,"Child closing write end of pipe\n");
 
                 close(fp[1]);   // All done writing to the pipe
-                exit(EXIT_FAILURE);
+                exit(EXIT_FAILURE); // Exit from child process
 
             }   // End of child process
 //---------------------------------------------------------------------------------------
@@ -280,7 +299,8 @@ char *host_lookup(char *host, char *ip, int time) {
                     }
                 }
                 (void)read(fp[0],buf,sizeof(buf)-1);
-                strcpy(ip,buf);
+
+                xastir_snprintf(ip, ip_size, "%s", buf);
 
                 if (debug_level & 1024)
                     fprintf(stderr,"Parent closing read end of pipe\n");
