@@ -1,9 +1,9 @@
 /*
- * $Id: igate.c,v 1.23 2003/06/06 23:57:17 we7u Exp $
+ * $Id: igate.c,v 1.41 2004/11/05 16:37:36 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2004  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -38,9 +38,9 @@
 #include <X11/Xatom.h>
 #include <X11/Shell.h>
 
+#include "xastir.h"
 #include "igate.h"
 #include "main.h"
-#include "xastir.h"
 #include "interface.h"
 #include "xa_config.h"
 #include "util.h"
@@ -199,7 +199,11 @@ int not_a_dupe(int queue_type, int port, char *line, int insert_mode) {
             // transmissions out RF have that character as well.
             if (debug_level & 1024)
                 fprintf(stderr,"3rd party HeardQ: %s\n",line);
-            strcpy(line2,c0+1);
+
+            xastir_snprintf(line2,
+                sizeof(line2),
+                "%s",
+                c0+1);
 
             break;
 
@@ -211,7 +215,10 @@ int not_a_dupe(int queue_type, int port, char *line, int insert_mode) {
 
             // No extra changes needed before parsing code, Example:
             // }VE7VFM-11>APW251,TCPIP,WE7U-14*::VE7VFM-9 :OK GOT EMAIL OK{058
-            strcpy(line2,line);
+            xastir_snprintf(line2,
+                sizeof(line2),
+                "%s",
+                line);
 
             if (debug_level & 1024)
                 fprintf(stderr," COMPLETE SENT PACKET: %s\n",line2);
@@ -234,9 +241,17 @@ int not_a_dupe(int queue_type, int port, char *line, int insert_mode) {
     c2 = strstr(line2, ":"); // Find end of path
 
     if ( (c1 != NULL) && (c2 != NULL) ) {           // Found both separators
-        strncpy(match_line,line2,(int)(c1 - line2));// Copy source/destination portion
+
+        // Copy source/destination portion
+        xastir_snprintf(match_line,
+            sizeof(match_line),
+            "%s",
+            line2);
         match_line[(int)(c1-line2)] = '\0';         // Terminate the substring
-        strcat(match_line,c2+1);                    // Copy info portion
+
+        strncat(match_line,                         // Copy info portion
+            c2+1,
+            sizeof(match_line) - strlen(match_line));
     }
     else {  // At least one separator was not found, copy entire string
         xastir_snprintf(match_line,
@@ -328,6 +343,7 @@ int not_a_dupe(int queue_type, int port, char *line, int insert_mode) {
                 case DEVICE_SERIAL_TNC:
                 case DEVICE_AX25_TNC:
                 case DEVICE_SERIAL_KISS_TNC:
+                case DEVICE_SERIAL_MKISS_TNC:
                 case DEVICE_NET_AGWPE:
                     fprintf(stderr,"        Found RF dupe: %s\n",match_line);
                     break;
@@ -365,8 +381,19 @@ int not_a_dupe(int queue_type, int port, char *line, int insert_mode) {
             // Allocate a new storage space for the record and fill
             // it in.
             temp = (DupeRecord *)malloc(sizeof(DupeRecord));
+
+            if (!temp) {
+                fprintf(stderr,"Couldn't allocate memory in not_a_dupe()\n");
+                return(1);  // Send back "not a dupe"
+            }
+
             temp->time = (time_t)sec_now();
-            strcpy(temp->data,match_line);
+
+            xastir_snprintf(temp->data,
+                sizeof(temp->data),
+                "%s",
+                match_line);
+
             temp->next = NULL;  // Will be the end of the linked list
 
             if (ptr_last == NULL) { // Queue is currently empty
@@ -412,6 +439,7 @@ void insert_into_heard_queue(int port, char *line) {
         case DEVICE_SERIAL_TNC:
         case DEVICE_AX25_TNC:
         case DEVICE_SERIAL_KISS_TNC:
+        case DEVICE_SERIAL_MKISS_TNC:
         case DEVICE_NET_AGWPE:
  
             // We're not using the dupe check function, but merely the
@@ -462,11 +490,21 @@ void output_igate_net(char *line, int port, int third_party) {
     if (line[0] == '\0')
         return;
 
+    // Don't igate packets read in from a log file (port -1).
+    // Packets from x_spider (port -2) are ok to igate.
+    if (port == -1)
+        return;
+
+//fprintf(stderr,"Igating: %s\n", line);
+
     // Should we Igate from RF->NET?
     if (operate_as_an_igate <= 0)
         return;
 
-    strcpy(temp,line);
+    xastir_snprintf(temp,
+        sizeof(temp),
+        "%s",
+        line);
 
     // Check for null call_sign field
     call_sign = strtok(temp,">");
@@ -487,10 +525,14 @@ void output_igate_net(char *line, int port, int third_party) {
     // seen in the path, do _not_ gate those packets into the
     // internet.
     //
+    // Don't gate OpenTrac expanded packets to the 'net.
+    //
     if ( (strstr(path,"TCPXX") != NULL)
-            || (strstr(path,"TCPIP") != NULL)
+            || (strstr(path,"TCPIP") != NULL && port >= 0) // x_spider ok
             || (strstr(path,"NOGATE") != NULL)
-            || (strstr(path,"RFONLY") != NULL) ) {
+            || (strstr(path,"RFONLY") != NULL)
+            || (strstr(path,"OPNTRK") != NULL)      // OpenTrac Packet
+            || (strstr(path,"OPNTRC") != NULL) ) {  // OpenTrac Packet
  
             if (log_igate && (debug_level & 1024) ) {
 
@@ -503,7 +545,7 @@ void output_igate_net(char *line, int port, int third_party) {
 
                 xastir_snprintf(temp,
                     sizeof(temp),
-                    "REJECT: Packet was gated before or shouldn't be gated\n");
+                    "REJECT: Packet was gated before or shouldn't be gated!\n");
                 log_data(LOGFILE_IGATE,temp);
 
                 fprintf(stderr,temp);
@@ -531,7 +573,30 @@ void output_igate_net(char *line, int port, int third_party) {
 
             xastir_snprintf(temp,
                 sizeof(temp),
-                "REJECT: Third party traffic\n");
+                "REJECT: Third party traffic!\n");
+            log_data(LOGFILE_IGATE,temp);
+
+            fprintf(stderr,temp);
+        }
+        return;
+    }
+
+    // Check for generic queries, which have a '?' mark as the first
+    // character in the message field.  We don't wish to gate these.
+    if (message[0] == '?') {
+
+        if (log_igate && (debug_level & 1024) ) {
+
+            xastir_snprintf(temp,
+                sizeof(temp),
+                "IGATE RF->NET(%c):%s\n",
+                third_party ? 'T':'N',
+                line);
+            log_data(LOGFILE_IGATE,temp);
+
+            xastir_snprintf(temp,
+                sizeof(temp),
+                "REJECT: Generic Query!\n");
             log_data(LOGFILE_IGATE,temp);
 
             fprintf(stderr,temp);
@@ -563,7 +628,7 @@ void output_igate_net(char *line, int port, int third_party) {
 
             xastir_snprintf(temp,
                 sizeof(temp),
-                "REJECT: From my call\n");
+                "REJECT: From my call!\n");
             log_data(LOGFILE_IGATE,temp);
 
             fprintf(stderr,temp);
@@ -576,7 +641,30 @@ void output_igate_net(char *line, int port, int third_party) {
 
 begin_critical_section(&devices_lock, "igate.c:output_igate_net" );
 
-    igate_options = devices[port].igate_options;
+    // If received from x_spider port or it's our own tactical call.
+    // Here are the special port numbers we might see:
+    // -1: We're reading in from a log file
+    // -2: Packet came from x_spider server port (therefore it's
+    //     already authenticated)
+    // -3: We're reading in tactical calls from file
+    //
+    if (port == -1)         // Packet came from a log file.
+        igate_options = 0;  // Don't igate it.
+
+    else if (port == -2)    // Packet came from x_spider server port
+        igate_options = 1;  // Ok to igate.
+
+    else if (port == -3)    // We're reading tactical call from file.
+        igate_options = 0;  // Don't igate it.
+
+    else if (port < -2)     // Errant port number.
+        igate_options = 0;  // Don't igate it.
+
+    else    // Port number is 0 or positive number.  A real port.
+            // Decide whether to igate it based on the port's
+            // configuration.
+        igate_options = devices[port].igate_options;
+
 
 end_critical_section(&devices_lock, "igate.c:output_igate_net" );
 
@@ -593,7 +681,7 @@ end_critical_section(&devices_lock, "igate.c:output_igate_net" );
 
             xastir_snprintf(temp,
                 sizeof(temp),
-                "REJECT: No RF->NET from input port [%d]\n",
+                "REJECT: No RF->NET from input port [%d]!\n",
                 port);
             log_data(LOGFILE_IGATE,temp);
 
@@ -655,6 +743,7 @@ end_critical_section(&devices_lock, "igate.c:output_igate_net" );
                 // means raw format, the last digit says to _not_
                 // use the unproto_igate path
                 output_my_data(data_txt,x,1,0,0,NULL);
+//fprintf(stderr,"Sending: %s\n", data_txt);
             }
         }
     }
@@ -675,6 +764,8 @@ void output_igate_rf(char *from, char *call, char *path, char *line, int port, i
     char temp[MAX_LINE_SIZE+20];
     int x;
     int first = 1;
+    char *ii;
+    char *jj;
 
 
     if ( (from == NULL) || (call == NULL) || (path == NULL) || (line == NULL) )
@@ -687,10 +778,11 @@ void output_igate_rf(char *from, char *call, char *path, char *line, int port, i
     if (operate_as_an_igate <= 1)
         return;
 
-    // Check for TCPXX* in string.  If found, we have an
+    // Check for TCPXX in string.  If found, we have an
     // unregistered net user.
-    if (strstr(path,"TCPXX*") != NULL) {
-        // "TCPXX*" was found in the header.  We have an
+    // I removed the trailing asterisk -we7u
+    if (strstr(path,"TCPXX") != NULL) {
+        // "TCPXX" was found in the header.  We have an
         // unregistered user.
         if (log_igate && (debug_level & 1024) ) {
             xastir_snprintf(temp,
@@ -709,6 +801,54 @@ void output_igate_rf(char *from, char *call, char *path, char *line, int port, i
         return;
     }
 
+    // Don't gate anything with NOGATE in it, in either direction.
+    // Same for OpenTrac packets.
+    if ( (strstr(path,"NOGATE") != NULL)
+         || (strstr(path,"OPNTRK") != NULL)     // OpenTrac Packet
+         || (strstr(path,"OPNTRC") != NULL) ) { // OpenTrac Packet
+        // "NOGATE" was found in the header.  Don't gate it.
+        if (log_igate && (debug_level & 1024) ) {
+            xastir_snprintf(temp,
+                sizeof(temp),
+                "IGATE NET->RF(%c):%s\n",
+                third_party ? 'T':'N',
+                line);
+            log_data(LOGFILE_IGATE,temp);
+
+            xastir_snprintf(temp,
+                sizeof(temp),
+                "REJECT: NOGATE found in path or shouldn't be gated!\n");
+            log_data(LOGFILE_IGATE,temp);
+            fprintf(stderr,temp);
+        }
+        return;
+    }
+
+    // Don't gate generic queries in any direction.  These packets
+    // have a '?' character after the initial ':' character.
+    //
+    ii = strstr(path,":");  // Find the first ':' character
+    jj = strstr(path,":?"); // Find ":?" combination
+
+    if ( (jj != NULL) && (ii == jj) ) {
+        // We found a generic query.  Don't gate it.
+        if (log_igate && (debug_level & 1024) ) {
+            xastir_snprintf(temp,
+                sizeof(temp),
+                "IGATE NET->RF(%c):%s\n",
+                third_party ? 'T':'N',
+                line);
+            log_data(LOGFILE_IGATE,temp);
+
+            xastir_snprintf(temp,
+                sizeof(temp),
+                "REJECT: Generic query!\n");
+            log_data(LOGFILE_IGATE,temp);
+            fprintf(stderr,temp);
+        }
+        return;
+    }
+ 
     // Check whether the source and destination calls have been
     // heard on local RF.
     if (!heard_via_tnc_in_past_hour(call)==1        // Haven't heard destination call in previous hour
@@ -729,12 +869,12 @@ void output_igate_rf(char *from, char *call, char *path, char *line, int port, i
         if (!heard_via_tnc_in_past_hour(call))
             xastir_snprintf(temp,
                 sizeof(temp),
-                "REJECT: Destination not heard on TNC within an hour %s\n",
+                "REJECT: Destination not heard on TNC within an hour %s!\n",
                 call );
         else
             xastir_snprintf(temp,
                 sizeof(temp),
-                "REJECT: RF->RF talk\n");
+                "REJECT: RF->RF talk!\n");
             log_data(LOGFILE_IGATE,temp);
             fprintf(stderr,temp);
         }
@@ -774,6 +914,7 @@ void output_igate_rf(char *from, char *call, char *path, char *line, int port, i
                 case DEVICE_SERIAL_TNC:
                 case DEVICE_AX25_TNC:
                 case DEVICE_SERIAL_KISS_TNC:
+                case DEVICE_SERIAL_MKISS_TNC:
                 case DEVICE_NET_AGWPE:
 
 begin_critical_section(&devices_lock, "igate.c:output_igate_rf" );
@@ -826,7 +967,7 @@ begin_critical_section(&devices_lock, "igate.c:output_igate_rf" );
 
                             xastir_snprintf(temp,
                                 sizeof(temp),
-                                "REJECT: NET->RF on port [%d]\n",
+                                "REJECT: NET->RF on port [%d]!\n",
                                 x);
                             log_data(LOGFILE_IGATE,temp);
                             fprintf(stderr,temp);
@@ -856,6 +997,9 @@ void add_NWS_stations(void) {
             NWS_station_data = tmp_ptr;
             max_NWS_stations += 10;
         }
+        else {
+            fprintf(stderr,"Unable to allocate more space for NWS_station_data\n");
+        }
     }
 }
 
@@ -992,10 +1136,11 @@ void output_nws_igate_rf(char *from, char *path, char *line, int port, int third
     if (operate_as_an_igate <= 1)
         return;
 
-    // Check for TCPXX* in string!  If found, we have an
+    // Check for TCPXX in string!  If found, we have an
     // unregistered net user.
-    if (strstr(path,"TCPXX*") != NULL) {
-        // "TCPXX*" was found in the header.  We have an
+    // I removed the trailing asterisk --we7u
+    if (strstr(path,"TCPXX") != NULL) {
+        // "TCPXX" was found in the header.  We have an
         // unregistered user.
         if (log_igate && (debug_level & 1024) ) {
             xastir_snprintf(temp,
@@ -1014,8 +1159,28 @@ void output_nws_igate_rf(char *from, char *path, char *line, int port, int third
         return;
     }
 
-    // no unregistered net user found in string
+    // no unregistered net user found in string.  Look for NOGATE
+    // next.
 
+    if ( strstr(path,"NOGATE") != NULL ) {
+        // "NOGATE" was found in the header.  Don't gate it.
+        if (log_igate && (debug_level & 1024) ) {
+            xastir_snprintf(temp,
+                sizeof(temp),
+                "NWS IGATE NET->RF(%c):%s\n",
+                third_party ? 'T':'N',
+                line);
+            log_data(LOGFILE_IGATE,temp);
+
+            xastir_snprintf(temp,
+                sizeof(temp),
+                "REJECT: NOGATE found in path!\n");
+            log_data(LOGFILE_IGATE,temp);
+            fprintf(stderr,temp);
+        }
+        return;
+    }
+ 
     // see if we can gate NWS messages
     if (!filethere(get_user_base_dir("data/nws-stations.txt"))) {
         if (log_igate && (debug_level & 1024) ) {
@@ -1089,6 +1254,7 @@ void output_nws_igate_rf(char *from, char *path, char *line, int port, int third
                 case DEVICE_SERIAL_TNC:
                 case DEVICE_AX25_TNC:
                 case DEVICE_SERIAL_KISS_TNC:
+                case DEVICE_SERIAL_MKISS_TNC:
                 case DEVICE_NET_AGWPE:
 
 begin_critical_section(&devices_lock, "igate.c:output_nws_igate_rf" );
@@ -1142,7 +1308,7 @@ begin_critical_section(&devices_lock, "igate.c:output_nws_igate_rf" );
 
                             xastir_snprintf(temp,
                                 sizeof(temp),
-                                "REJECT: NET->RF on port [%d]\n",
+                                "REJECT: NET->RF on port [%d]!\n",
                                 x);
                             log_data(LOGFILE_IGATE,temp);
                             fprintf(stderr,temp);
