@@ -1,9 +1,9 @@
 /*
- * $Id: lang.c,v 1.8 2003/05/20 17:34:10 we7u Exp $
+ * $Id: lang.c,v 1.11 2004/07/30 03:57:58 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2004  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -163,17 +163,25 @@ int load_language_file(char *filename) {
                                         if(strlen(temp_ptr)<=MAX_LANG_CODE) {
                                             lcok=1;
                                             for (lt=0; lt <lang_code_number && lcok; lt++) {
-                                                if(strcmp(lang_code[lt],temp_ptr)==0)
+                                                if(strcmp(lang_code[lt],temp_ptr)==0) {
                                                     lcok=0;
+                                                    break;
+                                                }
                                             }
                                             if(lcok) {
-                                                strcpy(lang_code[lang_code_number],temp_ptr);
+                                                xastir_snprintf(lang_code[lang_code_number],
+                                                    MAX_LANG_CODE+1,
+                                                    "%s",
+                                                    temp_ptr);
                                                 temp_ptr=strtok(NULL,"|");         /* get string */
                                                 if (temp_ptr!=NULL) {
                                                     data_len=(int)strlen(temp_ptr);
                                                     if ((buffer_len+data_len+1)< MAX_LANG_BUFFER) {
                                                         lang_code_ptr[lang_code_number]=lang_buffer+buffer_len;
-                                                        strcpy(lang_buffer+buffer_len,temp_ptr);
+                                                        xastir_snprintf(lang_buffer+buffer_len,
+                                                            MAX_LANG_BUFFER-buffer_len,
+                                                            "%s",
+                                                            temp_ptr);
                                                         lang_buffer[buffer_len+data_len]='\0';
                                                         buffer_len+=data_len+1;
                                                         temp_ptr=strtok(NULL,"|");      /* get hotkey */
