@@ -1,9 +1,9 @@
 /*
- * $Id: locate_gui.c,v 1.5 2003/02/20 09:51:35 we7u Exp $
+ * $Id: locate_gui.c,v 1.15 2004/10/02 18:08:20 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2004  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,9 +32,8 @@
 #include <Xbae/Matrix.h>
 #endif  // HAVE_XBAE_MATRIX_H
 
-#include "main.h"
 #include "xastir.h"
-#include "db.h"
+#include "main.h"
 #include "lang.h"
 #include "maps.h"
 
@@ -74,12 +73,12 @@ void locate_gui_init(void)
 {
     init_critical_section( &locate_station_dialog_lock );
     init_critical_section( &locate_place_dialog_lock );
-    strcpy(locate_station_call,"");
-    strcpy(locate_place_name,"");
-    strcpy(locate_state_name,"");
-    strcpy(locate_county_name,"");
-    strcpy(locate_quad_name,"");
-    strcpy(locate_type_name,"");
+    locate_station_call[0] = '\0';
+    locate_place_name[0] = '\0';
+    locate_state_name[0] = '\0';
+    locate_county_name[0] = '\0';
+    locate_quad_name[0] = '\0';
+    locate_type_name[0] = '\0';
 }
 
 
@@ -105,20 +104,162 @@ end_critical_section(&locate_station_dialog_lock, "locate_gui.c:Locate_station_d
 
 
 
+/*
+ * Look up detailed FCC/RAC info about the station
+ */
+
+// Determine whether it is a U.S. or Canadian callsign then search
+// through the appropriate database and present the results.
+
+void fcc_rac_lookup(Widget w, XtPointer clientData, XtPointer callData) {
+    char station_call[200];
+    char temp[1000];
+    char temp2[300];
+    char *temp_ptr;
+    FccAppl my_fcc_data;
+    rac_record my_rac_data;
+
+
+    // Snag station call
+    temp_ptr = XmTextFieldGetString(locate_station_data);
+    xastir_snprintf(station_call,
+        sizeof(station_call),
+        "%s",
+        temp_ptr);
+    XtFree(temp_ptr);
+
+    (void)remove_trailing_spaces(station_call);
+
+    to_upper(station_call);
+
+    switch (station_call[0]) {
+        case 'A':
+        case 'K':
+        case 'N':
+        case 'W':
+            if (search_fcc_data_appl(station_call, &my_fcc_data) == 1) {
+
+                xastir_snprintf(temp,
+                    sizeof(temp),
+                    "%s\n%s %s\n%s %s %s\n%s %s, %s %s, %s %s\n\n",
+                    langcode("STIFCC0001"),
+                    langcode("STIFCC0003"),
+                    my_fcc_data.name_licensee,
+                    langcode("STIFCC0004"),
+                    my_fcc_data.text_street,
+                    my_fcc_data.text_pobox,
+                    langcode("STIFCC0005"),
+                    my_fcc_data.city,
+                    langcode("STIFCC0006"),
+                    my_fcc_data.state,
+                    langcode("STIFCC0007"),
+                    my_fcc_data.zipcode);
+
+                popup_message_always(langcode("WPUPLSP007"),temp);
+            }
+            else {
+                xastir_snprintf(temp2,
+                    sizeof(temp2),
+                    "Callsign Not Found!\n");
+                popup_message_always(langcode("POPEM00001"),temp2);
+            }
+            break;
+        case 'V':
+            if (search_rac_data(station_call, &my_rac_data) == 1) {
+
+                xastir_snprintf(temp,
+                    sizeof(temp),
+                    "%s\n%s %s\n%s\n%s, %s\n%s\n",
+                    langcode("STIFCC0002"),
+                    my_rac_data.first_name,
+                    my_rac_data.last_name,
+                    my_rac_data.address,
+                    my_rac_data.city,
+                    my_rac_data.province,
+                    my_rac_data.postal_code);
+
+                    if (my_rac_data.qual_a[0] == 'A')
+                        strncat(temp,
+                            langcode("STIFCC0008"),
+                            sizeof(temp) - strlen(temp));
+
+                    if (my_rac_data.qual_d[0] == 'D')
+                        strncat(temp,
+                            langcode("STIFCC0009"),
+                            sizeof(temp) - strlen(temp));
+
+                    if (my_rac_data.qual_b[0] == 'B' && my_rac_data.qual_c[0] != 'C')
+                        strncat(temp,
+                            langcode("STIFCC0010"),
+                            sizeof(temp) - strlen(temp));
+
+                    if (my_rac_data.qual_c[0] == 'C')
+                        strncat(temp,
+                            langcode("STIFCC0011"),
+                            sizeof(temp) - strlen(temp));
+
+                    strncat(temp,
+                        "\n",
+                        sizeof(temp) - strlen(temp));
+
+                    if (strlen(my_rac_data.club_name) > 1) {
+                        xastir_snprintf(temp2,
+                            sizeof(temp2),
+                            "%s\n%s\n%s, %s\n%s\n",
+                            my_rac_data.club_name,
+                            my_rac_data.club_address,
+                            my_rac_data.club_city,
+                            my_rac_data.club_province,
+                            my_rac_data.club_postal_code);
+                        strncat(temp,
+                            temp2,
+                            sizeof(temp) - strlen(temp));
+                    }
+
+
+                popup_message_always(langcode("WPUPLSP007"),temp);
+            }
+            else {
+                // RAC code does its own popup in this case?
+                //fprintf(stderr, "Callsign not found\n");
+            }
+            break;
+        default:
+            xastir_snprintf(temp2,
+                sizeof(temp2),
+                "Not an FCC or RAC callsign!\n");
+            popup_message_always(langcode("POPEM00001"),temp2);
+            break;
+    }
+    Locate_station_destroy_shell(w, clientData, callData);
+}
+
+
+
+
+
 /*
  *  Locate a station by centering the map at its position
  */
 void Locate_station_now(Widget w, XtPointer clientData, XtPointer callData) {
     char temp2[200];
+    char *temp_ptr;
+
 
     /* find station and go there */
-    strcpy(locate_station_call,XmTextFieldGetString(locate_station_data));
+    temp_ptr = XmTextFieldGetString(locate_station_data);
+    xastir_snprintf(locate_station_call,
+        sizeof(locate_station_call),
+        "%s",
+        temp_ptr);
+    XtFree(temp_ptr);
+
     (void)remove_trailing_spaces(locate_station_call);
     /*fprintf(stderr,"looking for %s\n",locate_station_call);*/
     if (locate_station(da, locate_station_call, (int)XmToggleButtonGetState(locate_case_data),
                     (int)XmToggleButtonGetState(locate_match_data),1) ==0) {
         xastir_snprintf(temp2, sizeof(temp2), langcode("POPEM00002"), locate_station_call);
-        popup_message(langcode("POPEM00001"),temp2);
+        popup_message_always(langcode("POPEM00001"),temp2);
     }
     Locate_station_destroy_shell(w, clientData, callData);
 }
@@ -131,15 +272,17 @@ void Locate_station_now(Widget w, XtPointer clientData, XtPointer callData) {
 // for when we've received a Mic-E emergency packet.
 //
 void Locate_station(/*@unused@*/ Widget w, /*@unused@*/ XtPointer clientData, XtPointer callData) {
-    static Widget pane, form, button_ok, button_cancel, call, sep;
+    static Widget pane, form, button_locate, button_cancel, call,
+        button_lookup, sep;
     Atom delw;
-    int emergency_flag = (int) callData;
+    int emergency_flag = XTPOINTER_TO_INT(callData);
 
  
     if (!locate_station_dialog) {
 
 begin_critical_section(&locate_station_dialog_lock, "locate_gui.c:Locate_station" );
 
+        // Check whether it is an emergency locate function
         if (emergency_flag == 1) {
                 locate_station_dialog = XtVaCreatePopupShell(langcode("WPUPLSP006"),
                 xmDialogShellWidgetClass,Global.top,
@@ -161,7 +304,7 @@ begin_critical_section(&locate_station_dialog_lock, "locate_gui.c:Locate_station
                           NULL);
 
         form =  XtVaCreateWidget("Locate_station form",xmFormWidgetClass, pane,
-                            XmNfractionBase, 2,
+                            XmNfractionBase, 3,
                             XmNbackground, colors[0xff],
                             XmNautoUnmanage, FALSE,
                             XmNshadowThickness, 1,
@@ -236,7 +379,7 @@ begin_critical_section(&locate_station_dialog_lock, "locate_gui.c:Locate_station
                                       XmNbackground, colors[0xff],
                                       NULL);
 
-        button_ok = XtVaCreateManagedWidget(langcode("WPUPLSP005"),xmPushButtonGadgetClass, form,
+        button_lookup = XtVaCreateManagedWidget(langcode("WPUPLSP007"),xmPushButtonGadgetClass, form,
                                       XmNtopAttachment, XmATTACH_WIDGET,
                                       XmNtopWidget, sep,
                                       XmNtopOffset, 5,
@@ -252,7 +395,7 @@ begin_critical_section(&locate_station_dialog_lock, "locate_gui.c:Locate_station
                                       XmNtraversalOn, TRUE,
                                       NULL);
 
-        button_cancel = XtVaCreateManagedWidget(langcode("UNIOP00002"),xmPushButtonGadgetClass, form,
+        button_locate = XtVaCreateManagedWidget(langcode("WPUPLSP005"),xmPushButtonGadgetClass, form,
                                       XmNtopAttachment, XmATTACH_WIDGET,
                                       XmNtopWidget, sep,
                                       XmNtopOffset, 5,
@@ -260,15 +403,32 @@ begin_critical_section(&locate_station_dialog_lock, "locate_gui.c:Locate_station
                                       XmNbottomOffset, 5,
                                       XmNleftAttachment, XmATTACH_POSITION,
                                       XmNleftPosition, 1,
+                                      XmNleftOffset, 5,
                                       XmNrightAttachment, XmATTACH_POSITION,
                                       XmNrightPosition, 2,
+                                      XmNbackground, colors[0xff],
+                                      XmNnavigationType, XmTAB_GROUP,
+                                      XmNtraversalOn, TRUE,
+                                      NULL);
+
+        button_cancel = XtVaCreateManagedWidget(langcode("UNIOP00002"),xmPushButtonGadgetClass, form,
+                                      XmNtopAttachment, XmATTACH_WIDGET,
+                                      XmNtopWidget, sep,
+                                      XmNtopOffset, 5,
+                                      XmNbottomAttachment, XmATTACH_FORM,
+                                      XmNbottomOffset, 5,
+                                      XmNleftAttachment, XmATTACH_POSITION,
+                                      XmNleftPosition, 2,
+                                      XmNrightAttachment, XmATTACH_POSITION,
+                                      XmNrightPosition, 3,
                                       XmNrightOffset, 5,
                                       XmNbackground, colors[0xff],
                                       XmNnavigationType, XmTAB_GROUP,
                                       XmNtraversalOn, TRUE,
                                       NULL);
 
-        XtAddCallback(button_ok, XmNactivateCallback, Locate_station_now, locate_station_dialog);
+        XtAddCallback(button_lookup, XmNactivateCallback, fcc_rac_lookup, locate_station_dialog);
+        XtAddCallback(button_locate, XmNactivateCallback, Locate_station_now, locate_station_dialog);
         XtAddCallback(button_cancel, XmNactivateCallback, Locate_station_destroy_shell, locate_station_dialog);
 
         XmToggleButtonSetState(locate_case_data,FALSE,FALSE);
@@ -328,14 +488,51 @@ end_critical_section(&locate_place_dialog_lock, "locate_gui.c:Locate_place_destr
  *  Locate a place by centering the map at its position
  */
 void Locate_place_now(Widget w, XtPointer clientData, XtPointer callData) {
+    char *temp_ptr;
+
 
     /* find place and go there */
-    strcpy(locate_place_name, XmTextFieldGetString(locate_place_data));
-    strcpy(locate_state_name, XmTextFieldGetString(locate_state_data));
-    strcpy(locate_county_name, XmTextFieldGetString(locate_county_data));
-    strcpy(locate_quad_name, XmTextFieldGetString(locate_quad_data));
-    strcpy(locate_type_name, XmTextFieldGetString(locate_type_data));
-    strcpy(locate_gnis_filename, XmTextFieldGetString(locate_gnis_file_data));
+    temp_ptr = XmTextFieldGetString(locate_place_data);
+    xastir_snprintf(locate_place_name,
+        sizeof(locate_place_name),
+        "%s",
+        temp_ptr);
+    XtFree(temp_ptr);
+
+    temp_ptr = XmTextFieldGetString(locate_state_data);
+    xastir_snprintf(locate_state_name,
+        sizeof(locate_state_name),
+        "%s",
+        temp_ptr);
+    XtFree(temp_ptr);
+
+    temp_ptr = XmTextFieldGetString(locate_county_data);
+    xastir_snprintf(locate_county_name,
+        sizeof(locate_county_name),
+        "%s",
+        temp_ptr);
+    XtFree(temp_ptr);
+
+    temp_ptr = XmTextFieldGetString(locate_quad_data);
+    xastir_snprintf(locate_quad_name,
+        sizeof(locate_quad_name),
+        "%s",
+        temp_ptr);
+    XtFree(temp_ptr);
+
+    temp_ptr = XmTextFieldGetString(locate_type_data);
+    xastir_snprintf(locate_type_name,
+        sizeof(locate_type_name),
+        "%s",
+        temp_ptr);
+    XtFree(temp_ptr);
+
+    temp_ptr = XmTextFieldGetString(locate_gnis_file_data);
+    xastir_snprintf(locate_gnis_filename,
+        sizeof(locate_gnis_filename),
+        "%s",
+        temp_ptr);
+    XtFree(temp_ptr);
 
     (void)remove_trailing_spaces(locate_place_name);
     (void)remove_trailing_spaces(locate_state_name);
@@ -353,7 +550,7 @@ void Locate_place_now(Widget w, XtPointer clientData, XtPointer callData) {
             locate_gnis_filename,
             (int)XmToggleButtonGetState(locate_place_case_data),
             (int)XmToggleButtonGetState(locate_place_match_data)) ==0) {
-        popup_message(langcode("POPEM00025"),locate_place_name);
+        popup_message_always(langcode("POPEM00025"),locate_place_name);
     }
     Locate_place_destroy_shell(w, clientData, callData);
 }
