@@ -1,9 +1,9 @@
 /*
- * $Id: location.c,v 1.2 2003/01/24 00:34:53 we7u Exp $
+ * $Id: location.c,v 1.5 2004/01/26 16:18:21 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2004  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -74,17 +74,25 @@ void map_pos_last_position(void) {
 void map_pos(long mid_y, long mid_x, long sz) {
     // see also set_map_position() in db.c
 
+    // Set interrupt_drawing_now because conditions have changed
+    // (new map center).
+    interrupt_drawing_now++;
+
     set_last_position();
     mid_x_long_offset = mid_x;
     mid_y_lat_offset  = mid_y;
     scale_y = sz;
     scale_x = get_x_scale(mid_x,mid_y,scale_y);
     setup_in_view();  // flag all stations in screen view
-    create_image(da);
 
-    // We don't care whether or not this succeeds?
-    (void)XCopyArea(XtDisplay(da),pixmap_final,XtWindow(da),gc,0,0,screen_width,screen_height,0,0);
-
-    display_zoom_status();
+    // Request that a new image be created.  Calls create_image,
+    // XCopyArea, and display_zoom_status.
+    request_new_image++;
+    
+//    if (create_image(da)) {
+//        // We don't care whether or not this succeeds?
+//        (void)XCopyArea(XtDisplay(da),pixmap_final,XtWindow(da),gc,0,0,screen_width,screen_height,0,0);
+//        display_zoom_status();
+//    }
 }
 
