@@ -1,9 +1,9 @@
 /*
- * $Id: location_gui.c,v 1.5 2003/04/16 23:42:19 we7u Exp $
+ * $Id: location_gui.c,v 1.12 2004/09/17 19:56:56 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2004  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,12 +30,12 @@
 
 #include <Xm/XmAll.h>
 
-#include "main.h"
 #include "xastir.h"
+#include "main.h"
 #include "xa_config.h"
-#include "db.h"
 #include "util.h"
 #include "lang.h"
+#include "snprintf.h"
 
 
 Widget location_dialog = (Widget)NULL;
@@ -124,9 +124,15 @@ void location_view(/*@unused@*/ Widget w, /*@unused@*/ XtPointer clientData, /*@
                 if (!feof(f) && strlen(temp)>8) {
                     temp_ptr=strtok(temp,"|");  /* get the name */
                     if (temp_ptr!=NULL) {
-                        strncpy(name,temp,100);
+                        xastir_snprintf(name,
+                            sizeof(name),
+                            "%s",
+                            temp);
                         temp_ptr=strtok(NULL,"|");  /* get the pos */
-                        strncpy(pos,temp_ptr,100);
+                        xastir_snprintf(pos,
+                            sizeof(pos),
+                            "%s",
+                            temp_ptr);
                         if (strcmp(location,name)==0) {
                             (void)sscanf(pos,"%19s %19s %9s", s_lat, s_long, s_sz);
                             map_pos(convert_lat_s2l(s_lat),convert_lon_s2l(s_long),atol(s_sz));
@@ -164,7 +170,10 @@ void jump_sort(void) {
             if (!feof(f) && strlen(temp)>8) {
                 temp_ptr=strtok(temp,"|");  /* get the name */
                 if (temp_ptr!=NULL) {
-                    strncpy(name,temp,100);
+                    xastir_snprintf(name,
+                        sizeof(name),
+                        "%s",
+                        temp);
                     (void)sort_input_database(get_user_base_dir("data/locations_db.dat"),name,200);
                 }
             }
@@ -218,9 +227,15 @@ void location_delete(/*@unused@*/ Widget w, /*@unused@*/ XtPointer clientData, /
                     if (!feof(f) && strlen(temp)>8) {
                         temp_ptr=strtok(temp,"|");  /* get the name */
                         if (temp_ptr!=NULL) {
-                            strncpy(name,temp,100);
+                            xastir_snprintf(name,
+                                sizeof(name),
+                                "%s",
+                                temp);
                             temp_ptr=strtok(NULL,"|");  /* get the pos */
-                            strncpy(pos,temp_ptr,100);
+                            xastir_snprintf(pos,
+                                sizeof(pos),
+                                "%s",
+                                temp_ptr);
                             if (strcmp(location,name)!=0) {
                                 fprintf(fout,"%s|%s\n",name,pos);
                             }
@@ -242,8 +257,17 @@ void location_delete(/*@unused@*/ Widget w, /*@unused@*/ XtPointer clientData, /
     }
 
     if (ok==1){
-        strcpy(filen,get_user_base_dir("config/locations.sys"));
-        strcpy(filen_bak,get_user_base_dir("config/locations.sys-tmp"));
+
+        xastir_snprintf(filen,
+            sizeof(filen),
+            "%s",
+            get_user_base_dir("config/locations.sys"));
+
+        xastir_snprintf(filen_bak,
+            sizeof(filen_bak),
+            "%s",
+            get_user_base_dir("config/locations.sys-tmp"));
+
         (void)unlink(filen);
         (void)rename(filen_bak,filen);
     }
@@ -267,7 +291,14 @@ void location_add(/*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtPo
     Widget my_text = (Widget) clientData;
     int len,n,found;
 
-    strcpy(name,XmTextFieldGetString(my_text));
+
+    temp_ptr = XmTextFieldGetString(my_text);
+    xastir_snprintf(name,
+        sizeof(name),
+        "%s",
+        temp_ptr);
+    XtFree(temp_ptr);
+
     (void)remove_trailing_spaces(name);
     XmTextFieldSetString(my_text,"");
     /* should check for name used already */
@@ -297,16 +328,14 @@ void location_add(/*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtPo
             fout = fopen(get_user_base_dir("config/locations.sys"),"a");
             if (fout!=NULL) {
                 convert_lat_l2s(mid_y_lat_offset, s_lat, sizeof(s_lat), CONVERT_HP_NOSP);
-                //strcpy(s_lat+2,s_lat+3);
                 convert_lon_l2s(mid_x_long_offset, s_long, sizeof(s_long), CONVERT_HP_NOSP);
-                //strcpy(s_long+3,s_long+4);
                 fprintf(fout,"%s|%s %s %ld\n",name,s_lat,s_long,scale_y);
                 (void)fclose(fout);
             }
             else
                 fprintf(stderr,"Couldn't open file: %s\n", get_user_base_dir("config/locations.sys") );
         } else
-            popup_message(langcode("POPEM00022"),langcode("POPEM00023"));
+            popup_message_always(langcode("POPEM00022"),langcode("POPEM00023"));
 
         /* resort the list and put it back up */
         n=1;
@@ -314,7 +343,7 @@ void location_add(/*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtPo
         jump_sort();
         sort_list(get_user_base_dir("data/locations_db.dat"),200,location_list,&n);
     } else
-        popup_message(langcode("POPEM00022"),langcode("POPEM00024")); /* dupe name */
+        popup_message_always(langcode("POPEM00022"),langcode("POPEM00024")); /* dupe name */
 }
 
 
