@@ -1,9 +1,9 @@
 /*
- * $Id: main.h,v 1.44 2003/04/22 17:34:59 we7u Exp $
+ * $Id: main.h,v 1.71 2004/10/18 18:58:08 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2004  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -34,6 +34,12 @@
 #endif  // __linux__
 
 
+// Define this if your pthreads implementation uses SIGUSR1 signal.
+// This will disable our SIGUSR1 handler which allows us to create
+// snapshots on receipt of that signal.
+//#define OLD_PTHREADS
+
+
 // To enable the "Transmit Raw WX data" button in
 // Configure->Defaults dialog.  Warning:  If you enable this, enable
 // the button in Configure->Defaults, and are running a weather
@@ -43,11 +49,16 @@
 //#define TRANSMIT_RAW_WX
 
 
-extern char altnet_call[];
+extern int enable_server_port;
+
+
+extern char altnet_call[MAX_CALLSIGN+1];
 extern int altnet;
 extern Widget iface_da;
 extern FILE *read_file_ptr;
+extern int interrupt_drawing_now;
 
+ 
 #define VERSIONFRM  (!altnet?XASTIR_TOCALL:altnet_call) /* Packet version info */
 
 
@@ -61,21 +72,51 @@ extern FILE *read_file_ptr;
 
 
 #define VERSIONLABEL VERSIONTXT
+
+// NOTE:  This is out of date and not used anymore anyway.
 #define VERSIONMESSAGE "XASTIR Version: " VERSION "\n\nAmateur Station Tracking and Information Reporting\nby Frank Giannandrea, KC2GJS was KC0DGE\n   Code added by:\n   Richard Hagemeyer - VE3UNW,  Curt Mills - WE7U,\n   Mike Sims - KA9KIM,   Gerald Stueve - KE4NFJ,\n   Mark Grennan - KD5AMB,  Henk de Groot - PE1DNN,\n   Jim Sevilla - KD6VPE,  Jose R. Marte A. - HI8GN,\n   Michael G. Petry - N3NYN,   Lloyd Miller - VE6LFM,\n   Alessandro Frigeri - IK0YUP,\n   Chuck Byam - KG4IJB,   Rolf Bleher - DK7IN,   Ken Koster - N7IPB"
 
+// NOTE:  This is out of date and not used anymore anyway.
 #define ABOUTGNUL "XASTIR, Copyright (C) 1999, 2000 Frank Giannandrea\nXASTIR comes with ABSOLUTELY NO WARRANTY;\nThis is free software, and you are welcome\nto redistribute it under certain conditions;\nsee the GNU LICENSE for details.\n"
 
-#define MAX_CALL    20
-#define MAX_PHG     8
-#define MAX_COMMENT 80
+#define MAX_PHG      8
+#define MAX_COMMENT  80
 
-#define MAX_UNPROTO 100
+#define MAX_UNPROTO  100
 
 #define MAX_TNC_CHARS 128
 #define MAX_NET_CHARS 128
 #define MAX_GPS_CHARS 128
 #define MAX_WX_CHARS 4
 
+
+
+//////////////////////////////////////////////////////////////////////
+// These globals and prototypes are from:
+// http://lightconsulting.com/~thalakan/process-title-notes.html
+// They seems to work fine on Linux, but they only change the "ps"
+// listings, not the top listings.  I don't know why yet.
+
+/* Globals */
+//extern char **Argv = ((void *)0);
+//extern char *__progname, *__progname_full;
+//extern char *LastArgv = ((void *)0);
+
+/* Prototypes */
+extern void set_proc_title(char *fmt,...);
+extern void init_set_proc_title(int argc, char *argv[], char *envp[]);
+
+// New stuff defined by Xastir project:
+extern int my_argc;
+extern void *my_argv;
+extern void *my_envp;
+//////////////////////////////////////////////////////////////////////
+
+
+
+extern int skip_dupe_checking;
+extern int serial_char_pacing;  // Inter-character delay in ms.
+extern int disable_all_maps;
 extern int re_sort_maps;
 extern Widget trackme_button;
 extern int debug_level;
@@ -85,18 +126,18 @@ extern int transmit_now;
 extern char DATABASE_FILE[];
 extern char DATABASE_POINTER_FILE[];
 extern char DATABASE_POINTER_TEMP[];
-extern char ALERT_MAP_DIR[];
-extern char SELECTED_MAP_DIR[];
-extern char SELECTED_MAP_DATA[];
-extern char MAP_INDEX_DATA[];
-extern char AUTO_MAP_DIR[];
-extern char SYMBOLS_DIR[];
-extern char LOGFILE_IGATE[];
-extern char LOGFILE_TNC[];
-extern char LOGFILE_NET[];
-extern char LOGFILE_WX[];
+extern char ALERT_MAP_DIR[400];
+extern char SELECTED_MAP_DIR[400];
+extern char SELECTED_MAP_DATA[400];
+extern char MAP_INDEX_DATA[400];
+extern char AUTO_MAP_DIR[400];
+extern char SYMBOLS_DIR[400];
+extern char LOGFILE_IGATE[400];
+extern char LOGFILE_TNC[400];
+extern char LOGFILE_NET[400];
+extern char LOGFILE_WX[400];
 extern char HELP_FILE[];
-extern char SOUND_DIR[];
+extern char SOUND_DIR[400];
 extern time_t WX_ALERTS_REFRESH_TIME;
 extern time_t remove_ID_message_time;
 extern int pending_ID_message;
@@ -134,12 +175,14 @@ typedef struct _selections {
     int direct;
     int via_digi;
     int net;
+    int tactical;
     int old_data;
 
     int stations;
     int fixed_stations;
     int moving_stations;
     int weather_stations;
+    int CWOP_wx_stations;
     int objects;
     int weather_objects;
     int gauge_objects;
@@ -149,6 +192,7 @@ extern Selections Select_;
 
 typedef struct _what_to_display {
     int callsign;
+    int label_all_trackpoints;
     int symbol;
     int symbol_rotate;
     int trail;
@@ -184,7 +228,7 @@ extern int colors[256];
 extern int max_trail_colors;
 extern int trail_colors[32];
 extern int current_trail_color;
-extern int units_english_metric;
+extern int english_units;
 extern int do_dbstatus;
 extern int redraw_on_new_data;
 extern int redo_list;
@@ -202,27 +246,30 @@ extern int log_net_data;
 extern int log_wx;
 extern int snapshots_enabled;
 extern char user_dir[];
-extern char lang_to_use[];
+extern char lang_to_use[30];
 extern char my_group;
 extern char my_symbol;
-extern char my_phg[];
-extern char my_comment[];
+extern char my_phg[MAX_PHG+1];
+extern char my_comment[MAX_COMMENT+1];
 extern int map_background_color;
 extern int map_color_fill;
 extern int letter_style;
+extern int icon_outline_style;
 extern int wx_alert_style;
-extern char sound_command[];
+extern time_t map_refresh_interval;
+extern time_t map_refresh_time;
+extern char sound_command[90];
 extern pid_t last_sound_pid;
 extern int sound_play_new_station;
 extern int sound_play_new_message;
 extern int sound_play_prox_message;
 extern int sound_play_band_open_message;
 extern int sound_play_wx_alert_message;
-extern char sound_new_station[];
-extern char sound_new_message[];
-extern char sound_prox_message[];
-extern char sound_band_open_message[];
-extern char sound_wx_alert_message[];
+extern char sound_new_station[90];
+extern char sound_new_message[90];
+extern char sound_prox_message[90];
+extern char sound_band_open_message[90];
+extern char sound_wx_alert_message[90];
 extern int ATV_screen_ID;
 extern int festival_speak_ID;
 extern int festival_speak_new_station;
@@ -232,13 +279,16 @@ extern int festival_speak_band_opening;
 extern int festival_speak_new_message_alert;
 extern int festival_speak_new_message_body;
 extern int festival_speak_new_weather_alert;
-extern char prox_min[];
-extern char prox_max[];
+extern char prox_min[30];
+extern char prox_max[30];
 extern time_t sec_old;
 extern time_t sec_clear;
+extern int trail_segment_time;
+extern int trail_segment_distance;
+extern int RINO_download_interval;
 extern int dead_reckoning_timeout;
-extern char bando_min[];
-extern char bando_max[];
+extern char bando_min[30];
+extern char bando_max[30];
 extern int Display_packet_data_type;
 extern int menu_x;
 extern int menu_y;
@@ -259,13 +309,18 @@ extern int transmit_disable;
 extern int posit_tx_disable;
 extern int object_tx_disable;
 extern int map_chooser_expand_dirs;
+extern int request_new_image;
 
 extern int coordinate_system;
 #define USE_DDDDDD      0
 #define USE_DDMMMM      1
 #define USE_DDMMSS      2
 #define USE_UTM         3
+#define USE_UTM_SPECIAL 4
+#define USE_MGRS        5
 
+
+extern void HandlePendingEvents(XtAppContext app);
 extern void create_gc(Widget w);
 extern void Station_info(Widget w, XtPointer clientData, XtPointer calldata);
 extern void Station_List(Widget w, XtPointer clientData, XtPointer calldata);
@@ -273,6 +328,7 @@ extern void Window_Quit(Widget w, XtPointer client, XtPointer call);
 extern void Tracks_All_Clear(Widget w, XtPointer clientData, XtPointer callData);
 extern void Locate_station(Widget w, XtPointer clientData, XtPointer callData);
 extern void Locate_place(Widget w, XtPointer clientData, XtPointer callData);
+extern void Geocoder_place(Widget w, XtPointer clientData, XtPointer callData);
 extern void Display_Wx_Alert(Widget w, XtPointer clientData, XtPointer callData);
 extern void Auto_msg_option(Widget w, XtPointer clientData, XtPointer calldata);
 extern void Auto_msg_set(Widget w, XtPointer clientData, XtPointer calldata);
@@ -280,10 +336,12 @@ extern void Bulletins(Widget w, XtPointer clientData, XtPointer callData);
 extern void on_off_switch(int switchpos, Widget first, Widget second);
 extern void busy_cursor(Widget w);
 extern void pos_dialog(Widget w);
-extern void create_image(Widget w);
-extern void draw_tiger_map(Widget w);
+extern int create_image(Widget w);
+extern void draw_tiger_map (Widget w, char *filenm, int destination_pixmap);
+
 
 extern void locate_gui_init(void);
+extern void geocoder_gui_init(void);
 extern void location_gui_init(void);
 extern void view_message_gui_init(void);
 extern void wx_gui_init(void);
@@ -295,6 +353,8 @@ extern Widget text3;
 extern Widget text4;
 extern Widget log_indicator;
 extern void display_zoom_status(void);
+extern void Center_Zoom(Widget w, XtPointer clientData, XtPointer calldata);
+extern int center_zoom_override;
 extern void statusline(char *status_text,int update);
 extern int SayTextInit(void);
 extern int SayText(char *text);
@@ -311,6 +371,8 @@ extern Widget object_group_data;
 extern Widget object_symbol_data;
 extern void updateObjectPictureCallback(Widget w,XtPointer clientData,XtPointer callData);
 
+extern void Draw_All_CAD_Objects(Widget w);
+
 
 // unit conversion
 extern char un_alt[2+1];
