@@ -1,9 +1,9 @@
 /*
- * $Id: messages.c,v 1.23 2003/05/20 17:34:11 we7u Exp $
+ * $Id: messages.c,v 1.37 2004/09/28 21:53:03 gstueve Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2004  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -53,7 +53,6 @@
 
 #include "xastir.h"
 #include "main.h"
-#include "db.h"
 #include "messages.h"
 #include "util.h"
 #include "interface.h"
@@ -61,8 +60,8 @@
 
 char group_data_file[400];
 char *group_data_list = NULL;   // Need this NULL for Solaris!
-int  group_data_count;
-int  group_data_max;
+int  group_data_count = 0;
+int  group_data_max = 0;
 
 char message_counter[5+1];
 
@@ -88,7 +87,7 @@ begin_critical_section(&send_message_dialog_lock, "messages.c:clear_message_wind
             XtDestroyWidget(mw[i].send_message_dialog);
 
         mw[i].send_message_dialog = (Widget)NULL;
-        strcpy(mw[i].to_call_sign,"");
+        mw[i].to_call_sign[0] = '\0';
         mw[i].send_message_call_data = (Widget)NULL;
         mw[i].send_message_message_data = (Widget)NULL;
         mw[i].send_message_text = (Widget)NULL;
@@ -104,7 +103,7 @@ end_critical_section(&send_message_dialog_lock, "messages.c:clear_message_window
 
 static int group_comp(const void *a, const void *b) {
     if (!*(char *)a)
-      return ((int)(*(char *)b != '\0'));
+        return ((int)(*(char *)b != '\0'));
     return strcasecmp(a, b);
 }
 
@@ -116,6 +115,7 @@ void group_build_list(char *filename) {
     char *ptr;
     FILE *f;
     struct stat group_stat;
+    int i;
 
     if (group_data_count == group_data_max) {
         ptr = realloc(group_data_list, (size_t)(group_data_max+10)*10);
@@ -123,11 +123,28 @@ void group_build_list(char *filename) {
         if (ptr) {
             group_data_list = ptr;
             group_data_max += 10;
+
+//fprintf(stderr,                "group_data_max: %d\n", group_data_max);
+
+        }
+        else {
+            fprintf(stderr,
+                "Unable to allocate more memory for group_data_list (1)\n");
         }
     }
-    strcpy(&group_data_list[0], my_callsign);
-    strcpy(&group_data_list[10], "XASTIR");
-    group_data_count = 2;
+
+
+// Make sure we always listen for ourself, XASTIR, & our Version groups
+    xastir_snprintf(&group_data_list[0],10,"%s",my_callsign);
+    xastir_snprintf(&group_data_list[10],10,"XASTIR");
+    xastir_snprintf(&group_data_list[20],10,"%s",XASTIR_TOCALL);
+    group_data_count = 3;
+// If we are in special group look for messages.
+    if (altnet) {
+        xastir_snprintf(&group_data_list[group_data_count*10],10,"%s",altnet_call);
+        group_data_count++;
+    }
+//
 
     if (! stat(filename, &group_stat) )
         f = fopen(filename, "r");   // File exists
@@ -145,6 +162,13 @@ void group_build_list(char *filename) {
             if (ptr) {
                 group_data_list = ptr;
                 group_data_max += 10;
+
+//fprintf(stderr,                "group_data_max(2): %d\n", group_data_max);
+
+            }
+            else {
+                fprintf(stderr,
+                    "Unable to allocate more memory for group_data_list (2)\n");
             }
         }
         if (group_data_count < group_data_max) {
@@ -152,13 +176,19 @@ void group_build_list(char *filename) {
             (void)fgets(&group_data_list[group_data_count*10], 10, f);
             if ((ptr = strchr(&group_data_list[group_data_count*10], '\n')))
                 *ptr = '\0';
+            else
+                while ((i = fgetc(f)) != EOF && i != '\n'); // clean-up after long group name
 
+	// check for DOS EOL markup!
+            if ((ptr = strchr(&group_data_list[group_data_count*10], '\r')))
+                *ptr = '\0';
             if (group_data_list[group_data_count*10])
                 group_data_count++;
         }
     }
     (void)fclose(f);
     qsort(group_data_list, (size_t)group_data_count, 10, group_comp);
+    if (debug_level & 2) for (i = 0; i < group_data_count; i++) printf("Group %2d: %s\n", i, &group_data_list[i*10]);
 }
 
 
@@ -168,13 +198,21 @@ void group_build_list(char *filename) {
 static int group_active(char *from) {
     static struct stat current_group_stat;
     struct stat group_stat;
+    static char altgroup[10];
+
     (void)remove_trailing_spaces(from);
-    if (!stat(group_data_file, &group_stat) && (current_group_stat.st_size != group_stat.st_size ||
-    current_group_stat.st_mtime != group_stat.st_mtime || current_group_stat.st_ctime != group_stat.st_ctime)) {
-    group_build_list(group_data_file);
-    current_group_stat = group_stat;
+
+    // If we cycle to/from special group or file changes, rebuild group list.
+    if ((!stat(group_data_file, &group_stat)
+            && (current_group_stat.st_size != group_stat.st_size
+                || current_group_stat.st_mtime != group_stat.st_mtime
+                || current_group_stat.st_ctime != group_stat.st_ctime))
+                || (altgroup && strcasecmp(altgroup, VERSIONFRM))) {
+        group_build_list(group_data_file);
+        current_group_stat = group_stat;
+        xastir_snprintf(altgroup,sizeof(altgroup),"%s",VERSIONFRM);
     }
-    if (group_data_list != NULL)        // Causes segfault on Solaris 2.5 without this!
+    if (group_data_list != NULL)    // Causes segfault on Solaris 2.5 without this!
         return (int)(bsearch(from, group_data_list, (size_t)group_data_count, (size_t)10, group_comp) != NULL);
     else
         return(0);
@@ -187,6 +225,8 @@ static int group_active(char *from) {
 int look_for_open_group_data(char *to) {
     int i,found;
     char temp1[MAX_CALLSIGN+1];
+    char *temp_ptr;
+
 
 begin_critical_section(&send_message_dialog_lock, "messages.c:look_for_open_group_data" );
 
@@ -194,7 +234,14 @@ begin_critical_section(&send_message_dialog_lock, "messages.c:look_for_open_grou
      for(i = 0; i < MAX_MESSAGE_WINDOWS; i++) {
         /* find station  */
         if(mw[i].send_message_dialog != NULL) {
-            strcpy(temp1,XmTextFieldGetString(mw[i].send_message_call_data));
+
+            temp_ptr = XmTextFieldGetString(mw[i].send_message_call_data);
+            xastir_snprintf(temp1,
+                sizeof(temp1),
+                "%s",
+                temp_ptr);
+            XtFree(temp_ptr);
+
             (void)to_upper(temp1);
             /*fprintf(stderr,"Looking at call <%s> for <%s>\n",temp1,to);*/
             if(strcmp(temp1,to)==0) {
@@ -216,6 +263,7 @@ end_critical_section(&send_message_dialog_lock, "messages.c:look_for_open_group_
 int check_popup_window(char *from_call_sign, int group) {
     int i,found,j,ret;
     char temp1[MAX_CALLSIGN+1];
+    char *temp_ptr;
 
 
     ret =- 1;
@@ -226,7 +274,14 @@ begin_critical_section(&send_message_dialog_lock, "messages.c:check_popup_window
     for (i = 0; i < MAX_MESSAGE_WINDOWS; i++) {
         /* find station  */
         if (mw[i].send_message_dialog != NULL) {
-            strcpy(temp1,XmTextFieldGetString(mw[i].send_message_call_data));
+
+            temp_ptr = XmTextFieldGetString(mw[i].send_message_call_data);
+            xastir_snprintf(temp1,
+                sizeof(temp1),
+                "%s",
+                temp_ptr);
+            XtFree(temp_ptr);
+
             /*fprintf(stderr,"Looking at call <%s> for <%s>\n",temp1,from_call_sign);*/
             if (strcasecmp(temp1, from_call_sign) == 0) {
                 found = i;
@@ -258,7 +313,9 @@ end_critical_section(&send_message_dialog_lock, "messages.c:check_popup_window2"
         temp1[1] = '\0';
         } else
             temp1[0] = '\0';
-            strcat(temp1, from_call_sign);
+            strncat(temp1,
+                from_call_sign,
+                sizeof(temp1) - strlen(temp1));
             Send_message(appshell, temp1, NULL);
             update_messages(1);
             ret=i;
@@ -277,10 +334,10 @@ end_critical_section(&send_message_dialog_lock, "messages.c:check_popup_window2"
 
 void clear_outgoing_message(int i) {
     message_pool[i].active=MESSAGE_CLEAR;
-    strcpy(message_pool[i].to_call_sign,"");
-    strcpy(message_pool[i].from_call_sign,"");
-    strcpy(message_pool[i].message_line,"");
-    strcpy(message_pool[i].seq,"");
+    message_pool[i].to_call_sign[0] = '\0';
+    message_pool[i].from_call_sign[0] = '\0';
+    message_pool[i].message_line[0] = '\0';
+    message_pool[i].seq[0] = '\0';
     message_pool[i].active_time=0;;
     message_pool[i].next_time=0l;
     message_pool[i].tries=0;
@@ -290,6 +347,40 @@ void clear_outgoing_message(int i) {
 
 
 
+// Clear all pending transmit messages that are from us and to the
+// callsign listed.  Perhaps it'd be better to time it out instead
+// so that it still shows up in the message window?  Here we just
+// erase it.
+//
+void clear_outgoing_messages_to(char *callsign) {
+    int ii;
+
+
+//    fprintf(stderr,"Callsign: %s\n", callsign);
+
+    // Run through the entire outgoing message queue
+    for (ii = 0; ii < MAX_OUTGOING_MESSAGES; ii++) {
+
+        // If it matches the callsign we're talking to
+        if (strcasecmp(message_pool[ii].to_call_sign,callsign) == 0) {
+
+            // Clear it out.
+            message_pool[ii].active=MESSAGE_CLEAR;
+            message_pool[ii].to_call_sign[0] = '\0';
+            message_pool[ii].from_call_sign[0] = '\0';
+            message_pool[ii].message_line[0] = '\0';
+            message_pool[ii].seq[0] = '\0';
+            message_pool[ii].active_time=0;;
+            message_pool[ii].next_time=0l;
+            message_pool[ii].tries=0;
+        }
+    }
+}
+
+
+
+
+
 void reset_outgoing_messages(void) {
     int i;
 
@@ -433,14 +524,26 @@ void output_message(char *from, char *to, char *message, char *path) {
 
                 message_pool[i].active = MESSAGE_ACTIVE;
                 message_pool[i].wait_on_first_ack = wait_on_first_ack;
-                strcpy(message_pool[i].to_call_sign,to);
-                strcpy(message_pool[i].from_call_sign,from);
-                strcpy(message_pool[i].message_line,message_out);
+                xastir_snprintf(message_pool[i].to_call_sign,
+                    sizeof(message_pool[i].to_call_sign),
+                    "%s",
+                    to);
+                xastir_snprintf(message_pool[i].from_call_sign,
+                    sizeof(message_pool[i].from_call_sign),
+                    "%s",
+                    from);
+                xastir_snprintf(message_pool[i].message_line,
+                    sizeof(message_pool[i].message_line),
+                    "%s",
+                    message_out);
 
                 if (path != NULL)
-                    strncpy(message_pool[i].path,path,200);
+                    xastir_snprintf(message_pool[i].path,
+                        sizeof(message_pool[i].path),
+                        "%s",
+                        path);
                 else
-                    strcpy(message_pool[i].path,"");
+                    message_pool[i].path[0] = '\0';
 
 //                // We compute the base-90 sequence number here
 //                // This allows it to range from "!!" to "zz"
@@ -457,7 +560,7 @@ void output_message(char *from, char *to, char *message, char *path) {
                     message_counter[1]);
 
                 message_pool[i].active_time=0;
-                message_pool[i].next_time = (time_t)15l;
+                message_pool[i].next_time = (time_t)7l;
 
                 if (strcmp(from,"***")!= 0)
                     message_pool[i].tries = 0;
@@ -534,11 +637,20 @@ void transmit_message_data(char *to, char *message, char *path) {
 
 
 
+time_t last_check_and_transmit = (time_t)0l;
+
 void check_and_transmit_messages(time_t time) {
     int i;
     char temp[200];
     char to_call[40];
 
+
+    // Skip this function if we did it during this second already.
+    if (last_check_and_transmit == sec_now()) {
+        return;
+    }
+    last_check_and_transmit = sec_now();
+
     for (i=0; i<MAX_OUTGOING_MESSAGES;i++) {
         if (message_pool[i].active==MESSAGE_ACTIVE) {
             if (message_pool[i].wait_on_first_ack!=1) {
@@ -561,7 +673,10 @@ void check_and_transmit_messages(time_t time) {
                     // Reply/Ack protocol capable.
                     last_ack_ptr = get_most_recent_ack(to_call);
                     if (last_ack_ptr != NULL)
-                        strncpy(last_ack,last_ack_ptr,sizeof(last_ack));
+                        xastir_snprintf(last_ack,
+                            sizeof(last_ack),
+                            "%s",
+                            last_ack_ptr);
                     else
                         last_ack[0] = '\0';
                         
@@ -580,12 +695,12 @@ void check_and_transmit_messages(time_t time) {
 
                     //fprintf(stderr,"%d\n",(int)message_pool[i].next_time);
 
-                    // Start at 15 seconds for the interval.  Add 5 seconds to the
+                    // Start at 7 seconds for the interval.  Add 5 seconds to the
                     // interval each retry until we hit 90 seconds.  90 second
                     // intervals until retry 30, then start adding 30 seconds to
                     // the interval each time until we get to a 10 minute interval
                     // rate.  Keep transmitting at 10 minute intervals until we
-                    // hit MAX_RETRIES.
+                    // hit MAX_TRIES.
 
                     // Increase interval by 5 seconds each time
                     // until we hit 90 seconds
@@ -625,7 +740,10 @@ void check_and_transmit_messages(time_t time) {
                         // the message then needs this parameter to
                         // do another compare (to enable the Send Msg
                         // button again).
-                        strcpy(temp_to,message_pool[i].to_call_sign);
+                        xastir_snprintf(temp_to,
+                            sizeof(temp_to),
+                            "%s",
+                            message_pool[i].to_call_sign);
 
                         // Record a fake ack and add "TIMEOUT:" to
                         // the message.  This will be displayed in
@@ -662,12 +780,14 @@ void clear_acked_message(char *from, char *to, char *seq) {
     int found;
     char lowest[3];
     char temp1[MAX_CALLSIGN+1];
+    char *temp_ptr;
 
 
     (void)remove_trailing_spaces(seq);  // This is IMPORTANT here!!!
 
     //lowest=100000;
-    strncpy(lowest,"zz",2);     // Highest Base-90 2-char string
+    // Highest Base-90 2-char string
+    xastir_snprintf(lowest,sizeof(lowest),"zz");
     found=-1;
     for (i=0; i<MAX_OUTGOING_MESSAGES;i++) {
         if (message_pool[i].active==MESSAGE_ACTIVE) {
@@ -696,7 +816,10 @@ void clear_acked_message(char *from, char *to, char *seq) {
                                     //if (atoi(message_pool[i].seq)<lowest) {
                                     if (strncmp(message_pool[i].seq,lowest,2) < 0) {
                                         //lowest=atoi(message_pool[i].seq);
-                                        strncpy(lowest,message_pool[i].seq,2);
+                                        xastir_snprintf(lowest,
+                                            sizeof(lowest),
+                                            "%s",
+                                            message_pool[i].seq);
                                         found=i;
                                     }
                                 }
@@ -714,7 +837,14 @@ begin_critical_section(&send_message_dialog_lock, "messages.c:clear_acked_messag
                             for (ii=0;ii<MAX_MESSAGE_WINDOWS;ii++) {
                                 /* find station  */
                                 if (mw[ii].send_message_dialog!=NULL) {
-                                    strcpy(temp1,XmTextFieldGetString(mw[ii].send_message_call_data));
+
+                                    temp_ptr = XmTextFieldGetString(mw[ii].send_message_call_data);
+                                    xastir_snprintf(temp1,
+                                        sizeof(temp1),
+                                        "%s",
+                                        temp_ptr);
+                                    XtFree(temp_ptr);
+
                                     (void)to_upper(temp1);
                                     //fprintf(stderr,"%s\t%s\n",temp1,from);
 //                                    if (strcmp(temp1,from)==0) {
@@ -742,6 +872,8 @@ end_critical_section(&send_message_dialog_lock, "messages.c:clear_acked_message"
 
 
 
+// This routine is not currently used.
+//
 void send_queued(char *to) {
     int i;
 
