@@ -1,9 +1,9 @@
 /*
- * $Id: messages_gui.c,v 1.18 2003/04/12 00:07:41 we7u Exp $
+ * $Id: messages_gui.c,v 1.29 2004/10/02 18:08:20 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2004  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,13 +30,14 @@
 
 #include <Xm/XmAll.h>
 
-#include "main.h"
 #include "xastir.h"
-#include "db.h"
 #include "main.h"
 #include "lang.h"
 
 
+#define MAX_PATH 200
+
+
 Widget auto_msg_on, auto_msg_off;
 Widget auto_msg_dialog = (Widget)NULL;
 Widget auto_msg_set_data = (Widget)NULL;
@@ -131,7 +132,10 @@ void reverse_path(char *input_string) {
                 && (strncasecmp(&input_string[indexes[i]+1],"TCPIP",5) != 0) ) {
 
             // Snag each callsign into temp:
-            strncpy(temp, &input_string[indexes[i]+1], indexes[i+1] - indexes[i]);
+            xastir_snprintf(temp,
+                sizeof(temp),
+                "%s",
+                &input_string[indexes[i]+1]);
 
             // Massage temp until it resembles something we want to
             // use.
@@ -181,14 +185,14 @@ void reverse_path(char *input_string) {
     reverse_path[strlen(reverse_path) - 1] = '\0';
 
     // Save the new path back into the string we were given.
-    strcat(input_string,reverse_path);
+    strncat(input_string, reverse_path, len);
 }
 
 
 
 
 
-void get_path_data(char *callsign, char *path) {
+void get_path_data(char *callsign, char *path, int max_length) {
     DataRow *p_station;
 
 
@@ -217,14 +221,17 @@ void get_path_data(char *callsign, char *path) {
                 callsign,
                 new_path);
 
-        strcpy(path,new_path);
+        xastir_snprintf(path,
+            max_length,
+            "%s",
+            new_path);
     }
     else {  // Couldn't find callsign.  It's
             // not in our station database.
         if(debug_level & 2)
             fprintf(stderr,"Path from %s: No Path Known\n",callsign);
 
-        strcpy(path,"");
+        path[0] = '\0';
     }
 }
 
@@ -245,7 +252,7 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message_d
     }
 
     mw[i].send_message_dialog = (Widget)NULL;
-    strcpy(mw[i].to_call_sign,"");
+    mw[i].to_call_sign[0] = '\0';
     mw[i].send_message_call_data = (Widget)NULL;
     mw[i].send_message_message_data = (Widget)NULL;
     mw[i].send_message_text = (Widget)NULL;
@@ -261,7 +268,9 @@ end_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message_des
 void Check_new_call_messages( /*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtPointer callData) {
     int i, pos;
     char call_sign[MAX_CALLSIGN+1];
-    char path[200];
+    char path[MAX_PATH+1];
+    char *temp_ptr;
+
 
     i=atoi((char *)clientData);
     /* clear window*/
@@ -283,13 +292,19 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Check_new_call
         XtVaSetValues(mw[i].send_message_text,XmNcursorPosition,pos,NULL);
 
         // Go get the reverse path for the new callsign entered
-        strcpy(call_sign,XmTextFieldGetString(mw[i].send_message_call_data));
+        temp_ptr = XmTextFieldGetString(mw[i].send_message_call_data);
+        xastir_snprintf(call_sign,
+            sizeof(call_sign),
+            "%s",
+            temp_ptr);
+        XtFree(temp_ptr);
+
         // Try lowercase
-        get_path_data(call_sign, path);
+        get_path_data(call_sign, path, MAX_PATH);
         if (strlen(path) == 0) {
             // Try uppercase
             (void)to_upper(call_sign);
-            get_path_data(call_sign, path);
+            get_path_data(call_sign, path, MAX_PATH);
         }
         XmTextFieldSetString(mw[i].send_message_path, path);
     }
@@ -312,10 +327,12 @@ void Clear_messages( /*@unused@*/ Widget w, /*@unused@*/ XtPointer clientData, /
 
 
 void Send_message_now( /*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtPointer callData) {
-    char temp1[MAX_CALL+1];
+    char temp1[MAX_CALLSIGN+1];
     char temp2[302];
     char path[200];
     int i;
+    char *temp_ptr;
+
 
     i=atoi((char *)clientData);
 
@@ -324,14 +341,32 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message_n
     if (mw[i].send_message_dialog) {
 
         /* find station and go there */
-        strcpy(temp1,XmTextFieldGetString(mw[i].send_message_call_data));
+        temp_ptr = XmTextFieldGetString(mw[i].send_message_call_data);
+        xastir_snprintf(temp1,
+            sizeof(temp1),
+            "%s",
+            temp_ptr);
+        XtFree(temp_ptr);
+
         (void)remove_trailing_spaces(temp1);
         (void)to_upper(temp1);
 
-        strcpy(temp2,XmTextFieldGetString(mw[i].send_message_message_data));
+        temp_ptr = XmTextFieldGetString(mw[i].send_message_message_data);
+        xastir_snprintf(temp2,
+            sizeof(temp2),
+            "%s",
+            temp_ptr);
+        XtFree(temp_ptr);
+
         (void)remove_trailing_spaces(temp2);
 
-        strcpy(path,XmTextFieldGetString(mw[i].send_message_path));
+        temp_ptr = XmTextFieldGetString(mw[i].send_message_path);
+        xastir_snprintf(path,
+            sizeof(path),
+            "%s",
+            temp_ptr);
+        XtFree(temp_ptr);
+
         (void)remove_trailing_spaces(path);
         (void)to_upper(path);
 
@@ -366,17 +401,26 @@ end_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message_now
 
 
 void Clear_message_from( /*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtPointer callData) {
-    char temp1[MAX_CALL+1];
+    char temp1[MAX_CALLSIGN+1];
     int i;
+    char *temp_ptr;
 /* int pos;*/
 
+
     i=atoi((char *)clientData);
 
 begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Clear_message_from" );
 
     if (mw[i].send_message_dialog) {
+
         /* find station and go there */
-        strcpy(temp1,XmTextFieldGetString(mw[i].send_message_call_data));
+        temp_ptr = XmTextFieldGetString(mw[i].send_message_call_data);
+        xastir_snprintf(temp1,
+            sizeof(temp1),
+            "%s",
+            temp_ptr);
+        XtFree(temp_ptr);
+
         (void)remove_trailing_spaces(temp1);  
         (void)to_upper(temp1);
         /*fprintf(stderr,"Clear message from <%s> to <%s>\n",temp1,my_callsign);*/
@@ -393,8 +437,10 @@ end_critical_section(&send_message_dialog_lock, "messages_gui.c:Clear_message_fr
 
 
 void Clear_message_to( /*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtPointer callData) {
-    char temp1[MAX_CALL+1];
+    char temp1[MAX_CALLSIGN+1];
     int i;
+    char *temp_ptr;
+
 
     i=atoi((char *)clientData);
 
@@ -402,7 +448,13 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Clear_message_
 
     if (mw[i].send_message_dialog) {
         /* find station and go there */
-        strcpy(temp1,XmTextFieldGetString(mw[i].send_message_call_data));
+        temp_ptr = XmTextFieldGetString(mw[i].send_message_call_data);
+        xastir_snprintf(temp1,
+            sizeof(temp1),
+            "%s",
+            temp_ptr);
+        XtFree(temp_ptr);
+
         (void)remove_trailing_spaces(temp1);  
         (void)to_upper(temp1);
         /*fprintf(stderr,"Clear message to <%s>\n",temp1);*/
@@ -458,11 +510,34 @@ end_critical_section(&send_message_dialog_lock, "messages_gui.c:Clear_message_to
 
 
 
+void Clear_messages_to( /*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtPointer callData) {
+    char *temp_ptr;
+    char temp1[MAX_CALLSIGN+1];
+
+
+    temp_ptr = XmTextFieldGetString(mw[atoi(clientData)].send_message_call_data);
+        xastir_snprintf(temp1,
+            sizeof(temp1),
+            "%s",
+            temp_ptr);
+    XtFree(temp_ptr);
+
+    clear_outgoing_messages_to(temp1);
+    update_messages(1); // Force an update to the window
+}
+
+
+
+
+
 void Send_message_call( /*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtPointer callData) {
     char call[20];
 
     if(clientData !=NULL) {
-        strcpy(call,(char *)clientData);
+        xastir_snprintf(call,
+            sizeof(call),
+            "%s",
+            (char *)clientData);
         Send_message(Global.top,call,NULL);
     }           
 }
@@ -500,14 +575,27 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message"
         if (clientData != NULL) {
             substr(group,(char *)clientData, MAX_CALLSIGN);
             if (group[0] == '*') {
-                strcpy(mw[i].to_call_sign,"***");
+                xastir_snprintf(mw[i].to_call_sign,
+                    sizeof(mw[i].to_call_sign),
+                    "***");
+                mw[i].to_call_sign[3] = '\0';   // Terminate it
                 memmove(group, &group[1], strlen(group));
                 groupon=1;
                 box_len=100;
-            } else
-                strcpy(mw[i].to_call_sign, my_callsign);
-        } else
-            strcpy(mw[i].to_call_sign, my_callsign);
+            } else {
+                xastir_snprintf(mw[i].to_call_sign,
+                    sizeof(mw[i].to_call_sign),
+                    "%s",
+                    my_callsign);
+                mw[i].to_call_sign[MAX_CALLSIGN] = '\0';    // Terminate it
+            }
+        } else {
+            xastir_snprintf(mw[i].to_call_sign,
+                sizeof(mw[i].to_call_sign),
+                "%s",
+                my_callsign);
+            mw[i].to_call_sign[MAX_CALLSIGN] = '\0';    // Terminate it
+        }
 
         xastir_snprintf(temp, sizeof(temp), langcode(groupon==0 ? "WPUPMSB001": "WPUPMSB002"),
                 (i+1));
@@ -531,7 +619,7 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message"
         mw[i].form =  XtVaCreateWidget("Send_message form",
                 xmFormWidgetClass,
                 mw[i].pane,
-                XmNfractionBase, 5,
+                XmNfractionBase, 4,
                 XmNautoUnmanage, FALSE,
                 XmNshadowThickness, 1,
                 MY_FOREGROUND_COLOR,
@@ -620,30 +708,13 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message"
                 MY_BACKGROUND_COLOR,
                 NULL);
 
-        mw[i].button_clear_msg = XtVaCreateManagedWidget(langcode("WPUPMSB007"),
-                xmPushButtonGadgetClass, 
-                mw[i].form,
-                XmNleftAttachment, XmATTACH_WIDGET,
-                XmNleftWidget, mw[i].button_submit_call,
-                XmNleftOffset, 10,
-                XmNtopAttachment, XmATTACH_NONE,
-                XmNbottomAttachment, XmATTACH_FORM,
-                XmNbottomOffset, 80,
-                XmNrightAttachment, XmATTACH_NONE,
-                XmNnavigationType, XmTAB_GROUP,
-                XmNtraversalOn, TRUE,
-                MY_FOREGROUND_COLOR,
-                MY_BACKGROUND_COLOR,
-                NULL);
-
-//WE7U
         mw[i].path = XtVaCreateManagedWidget(langcode("WPUPMSB010"),
                 xmLabelWidgetClass, mw[i].form,
                 XmNtopAttachment, XmATTACH_NONE,
                 XmNbottomAttachment, XmATTACH_FORM,
                 XmNbottomOffset, 85,
                 XmNleftAttachment, XmATTACH_WIDGET,
-                XmNleftWidget, mw[i].button_clear_msg,
+                XmNleftWidget, mw[i].button_submit_call,
                 XmNleftOffset, 10,
                 XmNrightAttachment, XmATTACH_NONE,
                 MY_FOREGROUND_COLOR,
@@ -707,6 +778,38 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message"
                 XmNtraversalOn, TRUE,
                 NULL);
 
+        mw[i].button_clear_old_msgs = XtVaCreateManagedWidget(langcode("WPUPMSB007"),
+                xmPushButtonGadgetClass, 
+                mw[i].form,
+                XmNleftAttachment, XmATTACH_POSITION,
+                XmNleftPosition, 0,
+                XmNrightAttachment, XmATTACH_POSITION,
+                XmNrightPosition, 1,
+                XmNtopAttachment, XmATTACH_NONE,
+                XmNbottomAttachment, XmATTACH_FORM,
+                XmNbottomOffset, 5,
+                XmNnavigationType, XmTAB_GROUP,
+                XmNtraversalOn, TRUE,
+                MY_FOREGROUND_COLOR,
+                MY_BACKGROUND_COLOR,
+                NULL);
+
+        mw[i].button_clear_pending_msgs = XtVaCreateManagedWidget(langcode("WPUPMSB011"),
+                xmPushButtonGadgetClass, 
+                mw[i].form,
+                XmNleftAttachment, XmATTACH_POSITION,
+                XmNleftPosition, 1,
+                XmNrightAttachment, XmATTACH_POSITION,
+                XmNrightPosition, 2,
+                XmNtopAttachment, XmATTACH_NONE,
+                XmNbottomAttachment, XmATTACH_FORM,
+                XmNbottomOffset, 5,
+                XmNnavigationType, XmTAB_GROUP,
+                XmNtraversalOn, TRUE,
+                MY_FOREGROUND_COLOR,
+                MY_BACKGROUND_COLOR,
+                NULL);
+
         mw[i].button_ok = XtVaCreateManagedWidget(langcode("WPUPMSB009"),
                 xmPushButtonGadgetClass, 
                 mw[i].form,
@@ -714,9 +817,9 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message"
                 XmNbottomAttachment, XmATTACH_FORM,
                 XmNbottomOffset, 5,
                 XmNleftAttachment, XmATTACH_POSITION,
-                XmNleftPosition, 1,
+                XmNleftPosition, 2,
                 XmNrightAttachment, XmATTACH_POSITION,
-                XmNrightPosition, 2,
+                XmNrightPosition, 3,
                 XmNnavigationType, XmTAB_GROUP,
                 XmNtraversalOn, TRUE,
                 MY_FOREGROUND_COLOR,
@@ -746,17 +849,19 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message"
  
 // Note group messages isn't implemented fully yet.  When it is, the following might have
 // to change again:
-//        XtAddCallback(mw[i].button_clear_msg, XmNactivateCallback, groupon == 0 ? Clear_message_from: Clear_message_to,
+//        XtAddCallback(mw[i].button_clear_old_msgs, XmNactivateCallback, groupon == 0 ? Clear_message_from: Clear_message_to,
 //                (XtPointer)mw[i].win);
-        XtAddCallback(mw[i].button_clear_msg, XmNactivateCallback, Clear_message_to_from, (XtPointer)mw[i].win);
+        XtAddCallback(mw[i].button_clear_old_msgs, XmNactivateCallback, Clear_message_to_from, (XtPointer)mw[i].win);
 
-        XtAddCallback(mw[i].button_submit_call, XmNactivateCallback,  Check_new_call_messages, (XtPointer)mw[i].win);
+        XtAddCallback(mw[i].button_clear_pending_msgs, XmNactivateCallback, Clear_messages_to, (XtPointer)mw[i].win);
+
+        XtAddCallback(mw[i].button_submit_call, XmNactivateCallback, Check_new_call_messages, (XtPointer)mw[i].call);
 
         if (clientData != NULL) {
             char path[200];
 
             XmTextFieldSetString(mw[i].send_message_call_data, group);
-            get_path_data(group, path);
+            get_path_data(group, path, MAX_PATH);
             XmTextFieldSetString(mw[i].send_message_path, path);
         }
 
@@ -792,7 +897,7 @@ end_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message" );
 /************************* Auto msg **************************************/
 /*************************************************************************/
 void Auto_msg_option( /*@unused@*/ Widget w, /*@unused@*/ XtPointer clientData, /*@unused@*/ XtPointer calldata) {
-    int item_no = (int) clientData;
+    int item_no = XTPOINTER_TO_INT(clientData);
 
     if (item_no)
         auto_reply = 1;
@@ -823,10 +928,18 @@ end_critical_section(&auto_msg_dialog_lock, "messages_gui.c:Auto_msg_destroy_she
 
 void Auto_msg_set_now(Widget w, XtPointer clientData, XtPointer callData) {
     char temp[110];
+    char *temp_ptr;
+
+
+    temp_ptr = XmTextFieldGetString(auto_msg_set_data);
+    substr(temp, temp_ptr, 99);
+    XtFree(temp_ptr);
 
-    substr(temp,XmTextFieldGetString(auto_msg_set_data),99);
     (void)remove_trailing_spaces(temp);
-    strcpy(auto_reply_message,temp);
+    xastir_snprintf(auto_reply_message,
+        sizeof(auto_reply_message),
+        "%s",
+        temp);
     Auto_msg_destroy_shell(w, clientData, callData);
 }
 
