@@ -1,9 +1,9 @@
 /*
- * $Id: popup_gui.c,v 1.12 2003/06/06 23:57:17 we7u Exp $
+ * $Id: popup_gui.c,v 1.17 2004/09/17 19:46:06 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2004  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,8 +32,8 @@
 
 #include <Xm/XmAll.h>
 
-#include "main.h"
 #include "xastir.h"
+#include "main.h"
 #include "popup.h"
 #include "main.h"
 #include "lang.h"
@@ -103,22 +103,30 @@ end_critical_section(&popup_message_dialog_lock, "popup_gui.c:popup_message_dest
 
 
 
+time_t popup_time_out_check_last = (time_t)0l;
+
 void popup_time_out_check(void) {
     int i;
 
-    for (i=0;i<MAX_POPUPS;i++) {
-        if (pw[i].popup_message_dialog!=NULL) {
-            if ((sec_now()-pw[i].sec_opened)>MAX_POPUPS_TIME) {
-                XtPopdown(pw[i].popup_message_dialog);
+    // Check only every two minutes or so
+    if (popup_time_out_check_last + 120 < sec_now()) {
+        popup_time_out_check_last = sec_now();
+
+        for (i=0;i<MAX_POPUPS;i++) {
+            if (pw[i].popup_message_dialog!=NULL) {
+                if ((sec_now()-pw[i].sec_opened)>MAX_POPUPS_TIME) {
+                    XtPopdown(pw[i].popup_message_dialog);
 
 begin_critical_section(&popup_message_dialog_lock, "popup_gui.c:popup_time_out_check" );
 
-                XtDestroyWidget(pw[i].popup_message_dialog);
-                pw[i].popup_message_dialog = (Widget)NULL;
-                pw[i].popup_message_data = (Widget)NULL;
+                    XtDestroyWidget(pw[i].popup_message_dialog);
+                    pw[i].popup_message_dialog = (Widget)NULL;
+                    pw[i].popup_message_data = (Widget)NULL;
 
 end_critical_section(&popup_message_dialog_lock, "popup_gui.c:popup_time_out_check" );
 
+                }
+
             }
         }
     }
@@ -128,7 +136,7 @@ end_critical_section(&popup_message_dialog_lock, "popup_gui.c:popup_time_out_che
 
 
 
-void popup_message(char *banner, char *message) {
+void popup_message_always(char *banner, char *message) {
     XmString msg_str;
     int j,i;
     Atom delw;
@@ -217,6 +225,33 @@ end_critical_section(&popup_message_dialog_lock, "popup_gui.c:popup_message" );
 
 
 
+#ifndef HAVE_ERROR_POPUPS
+//
+// We'll write to STDERR instead since the user doesn't want to see
+// any error popups.  Add a timestamp to the front so we know when
+// the errors happened.
+//
+void popup_message(char *banner, char *message) {
+    char timestring[110];
+
+    get_timestamp(timestring);
+    fprintf(stderr, "%s:\n\t%s  %s\n\n", timestring, banner, message);
+}
+#else   // HAVE_ERROR_POPUPS
+//
+// The user wishes to see popup error messages.  Call the routine
+// above which does so.
+//
+void popup_message(char *banner, char *message) {
+    popup_message_always(banner, message);
+}
+#endif  // HAVE_ERROR_POPUPS
+
+
+
+
+
+
 // Must make sure that fonts are not loaded again and again, as this
 // takes a big chunk of memory each time.  Can you say "memory
 // leak"?
