@@ -1,9 +1,9 @@
 /*
- * $Id: sound.c,v 1.4 2003/02/22 00:58:42 we7u Exp $
+ * $Id: sound.c,v 1.10 2004/08/19 06:38:21 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2004  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,6 +32,7 @@
 #include <stdlib.h>
 #include <string.h>
 
+#include "xastir.h"
 #include "main.h"
 
 
@@ -39,23 +40,44 @@
 pid_t play_sound(char *sound_cmd, char *soundfile) {
     pid_t sound_pid;
     char command[600];
-    char file[600];
 
     sound_pid=0;
     if (strlen(sound_cmd)>3 && strlen(soundfile)>1) {
         if (last_sound_pid==0) {
+
+            // Create a new process to run in
             sound_pid = fork();
             if (sound_pid!=-1) {
                 if(sound_pid==0) {
-                    strcpy(file,SOUND_DIR);
-                    strcat(file,"/");
-                    strcat(file,soundfile);
-                    xastir_snprintf(command, sizeof(command), "%s %s", sound_cmd, file);
-                    /*fprintf(stderr,"PS%d:%s\n",sound_pid,file);*/
+// This is the child process
+
+
+                    // Change the name of the new child process.  So
+                    // far this only works for "ps" listings, not
+                    // for "top".  This code only works on Linux.
+                    // For BSD use setproctitle(3), NetBSD can use
+                    // setprogname(2).
+#ifdef __linux__
+                    init_set_proc_title(my_argc, my_argv, my_envp);
+                    set_proc_title("%s", "festival process (xastir)");
+                    //printf("DEBUG: %s\n", Argv[0]);
+#endif  // __linux__
+
+
+                    xastir_snprintf(command,
+                        sizeof(command),
+                        "%s %s/%s",
+                        sound_cmd,
+                        SOUND_DIR,
+                        soundfile);
+
                     (void)system(command);  // Note we're not caring about whether it succeeded or not
-                    exit(0);
-                } else
+                    exit(0);    // Exits only this process, not Xastir itself
+                }
+                else {
+// This is the parent process
                     last_sound_pid=sound_pid;
+                }
             } else
                 fprintf(stderr,"Error! trying to play sound\n");
         } else {
