@@ -1,9 +1,9 @@
 /*
- * $Id: track_gui.c,v 1.23 2003/06/07 00:12:09 we7u Exp $
+ * $Id: track_gui.c,v 1.34 2004/09/17 19:56:56 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2004  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,13 +32,12 @@
 #include <unistd.h>
 #include <Xm/XmAll.h>
 
-#include "main.h"
 #include "xastir.h"
-#include "db.h"
 #include "main.h"
 #include "lang.h"
 #include "popup.h"
 #include "util.h"
+#include "xa_config.h"
 
 Widget track_station_dialog = (Widget)NULL;
 Widget track_station_data = (Widget)NULL;
@@ -67,14 +66,20 @@ int posit_start = 336;
 int posit_length = 336;
 
 
+
+
+
 void track_gui_init(void)
 {
     init_critical_section( &track_station_dialog_lock );
     init_critical_section( &download_findu_dialog_lock );
-    strcpy(tracking_station_call,"");
+    tracking_station_call[0] = '\0';
 }
 
 
+
+
+
 /**** Track STATION ******/
 
 
@@ -100,7 +105,7 @@ void Track_station_clear(Widget w, XtPointer clientData, XtPointer callData) {
     /* clear station */
     track_station_on=0;
     //track_station_data=NULL;
-    //strcpy(tracking_station_call,"");
+    //tracking_station_call[0] = '\0';
 
     // Clear the TrackMe button as well
     XmToggleButtonSetState(trackme_button,FALSE,TRUE);
@@ -114,14 +119,25 @@ void Track_station_clear(Widget w, XtPointer clientData, XtPointer callData) {
 
 
 void Track_station_now(Widget w, XtPointer clientData, XtPointer callData) {
-    char temp[MAX_CALL+1];
+    char temp[MAX_CALLSIGN+1];
     char temp2[200];
     int found = 0;
+    char *temp_ptr;
+
 
     /* find station and go there */
-    strcpy(temp,XmTextFieldGetString(track_station_data));
+    temp_ptr = XmTextFieldGetString(track_station_data);
+    xastir_snprintf(temp,
+        sizeof(temp),
+        "%s",
+        temp_ptr);
+    XtFree(temp_ptr);
+
     (void)remove_trailing_spaces(temp);
-    strcpy(tracking_station_call,temp);
+    xastir_snprintf(tracking_station_call,
+        sizeof(tracking_station_call),
+        "%s",
+        temp);
     track_case  = (int)XmToggleButtonGetState(track_case_data);
     track_match = (int)XmToggleButtonGetState(track_match_data);
     found = locate_station(da, temp, track_case, track_match, 0);
@@ -132,13 +148,13 @@ void Track_station_now(Widget w, XtPointer clientData, XtPointer callData) {
         track_station_on = 1;   // Track it whether we've seen it yet or not
         if (!found) {
             xastir_snprintf(temp2, sizeof(temp2), langcode("POPEM00026"), temp);
-            popup_message(langcode("POPEM00025"),temp2);
+            popup_message_always(langcode("POPEM00025"),temp2);
         }
     } else {
-        strcpy(tracking_station_call,""); // Empty it out again
+        tracking_station_call[0] = '\0';    // Empty it out again
         track_station_on = 0;
         xastir_snprintf(temp2, sizeof(temp2), langcode("POPEM00002"), temp);
-        popup_message(langcode("POPEM00003"),temp2);
+        popup_message_always(langcode("POPEM00003"),temp2);
     }
 
     track_station_destroy_shell(w, clientData, callData);
@@ -377,7 +393,7 @@ end_critical_section(&download_findu_dialog_lock, "track_gui.c:Download_trail_de
 
 
 void Download_trail_now(Widget w, XtPointer clientData, XtPointer callData) {
-    char temp[MAX_CALL+1];
+    char temp[MAX_CALLSIGN+1];
     char fileimg[400];
 #ifdef HAVE_LIBCURL
 #else
@@ -385,32 +401,58 @@ void Download_trail_now(Widget w, XtPointer clientData, XtPointer callData) {
     char tempfile[500];
 #endif  // HAVE_WGET
 #endif
-    uid_t user_id;
-    struct passwd *user_info;
-    char username[20];
     char log_filename[200];
+    char *temp_ptr;
 
 
     busy_cursor(appshell);
 
-    // Fetch my user info
-    user_id=getuid();
-    user_info=getpwuid(user_id);
-    // Fetch the login name
-    strcpy(username,user_info->pw_name);
+    xastir_snprintf(log_filename,
+        sizeof(log_filename),
+        "%s/map.log",
+        get_user_base_dir("tmp"));
+
+    // Erase any previously existing local file by the same name.
+    // This avoids the problem of having an old tracklog here and
+    // the code trying to display it when the download fails.
+    unlink( log_filename );
 
-    xastir_snprintf(log_filename, sizeof(log_filename), "/var/tmp/xastir_%s_map.log", username);
 
     XmScaleGetValue(posit_start_value , &posit_start);
     XmScaleGetValue(posit_length_value , &posit_length);
     /* find station and go there */
-    strcpy(temp,XmTextFieldGetString(download_trail_station_data));
+    temp_ptr = XmTextFieldGetString(download_trail_station_data);
+    xastir_snprintf(temp,
+        sizeof(temp),
+        "%s",
+        temp_ptr);
+    XtFree(temp_ptr);
+
     (void)remove_trailing_spaces(temp);
-    strcpy(download_trail_station_call,temp);
+   
+    xastir_snprintf(download_trail_station_call,
+        sizeof(download_trail_station_call),
+        "%s",
+        temp);        
     //Download_trail_destroy_shell(w, clientData, callData);
 
+
+// New URL's for findu.  The second one looks very promising.
+//http://www.findu.com/cgi-bin/raw.cgi?call=k4hg-8&time=1
+//http://www.findu.com/cgi-bin/rawposit.cgi?call=k4hg-8&time=1
+//
+// The last adds this to the beginning of the line:
+//
+//      "20030619235323,"
+//
+// which is a date/timestamp.  We'll need to do some extra stuff
+// here in order to actually use that date/timestamp though.
+// Setting the read_file_ptr to the downloaded file won't do it.
+
+
     xastir_snprintf(fileimg, sizeof(fileimg),
-        "http://www.findu.com/cgi-bin/rawposit.cgi?call=%s&start=%d&length=%d",
+        "http://www.findu.com/cgi-bin/rawposit.cgi?call=%s&start=%d&length=%d",         // Old
+//        "http://www.findu.com/cgi-bin/rawposit.cgi?call=%s&start=%d&length=%d&time=1",// New
         download_trail_station_call,posit_start,posit_length);
 #ifdef HAVE_LIBCURL
     if (curl_getfile(fileimg, log_filename)) {
@@ -457,6 +499,9 @@ void Download_trail_now(Widget w, XtPointer clientData, XtPointer callData) {
 }
 
 
+
+
+
 void Reset_posit_length_max(Widget w, XtPointer clientData, XtPointer callData) {
 
     int temp;
@@ -475,6 +520,8 @@ void Reset_posit_length_max(Widget w, XtPointer clientData, XtPointer callData)
 
 
 
+
+
 void Download_findu_trail( /*@unused@*/ Widget w, /*@unused@*/ XtPointer clientData, /*@unused@*/ XtPointer callData) {
     static Widget pane, my_form, button_ok, button_cancel, call, sep;
     Atom delw;
