@@ -1,9 +1,9 @@
 /*
- * $Id: util.h,v 1.19 2003/06/04 16:05:35 we7u Exp $
+ * $Id: util.h,v 1.28 2004/10/29 20:00:52 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2004  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -29,6 +29,9 @@
 #include "db.h"
 #include <pthread.h>
 
+extern char *remove_leading_spaces(char *data);
+extern char *remove_trailing_spaces(char *data);
+extern char *remove_trailing_asterisk(char *data);
 extern int  position_amb_chars;
 extern void start_timer(void);
 extern void stop_timer(void);
@@ -50,7 +53,9 @@ extern char *compress_posit(const char *lat, const char group, const char *lon,
                 const int course, const int speed, const char *phg);
 
 extern int  position_defined(long lat, long lon, int strict);
+extern void convert_screen_to_xastir_coordinates(int x, int y, long *lat, long *lon);
 extern void convert_xastir_to_UTM_str(char *str, int str_len, long x, long y);
+extern void convert_xastir_to_MGRS_str(char *str, int str_len, long x, long y, int nice_format);
 extern void convert_xastir_to_UTM(double *easting, double *northing, char *zone, int zone_len, long x, long y);
 extern void convert_UTM_to_xastir(double easting, double northing, char *zone, long *x, long *y);
 extern void convert_lat_l2s(long lat, char *str, int str_len, int type);
@@ -71,6 +76,8 @@ extern void log_data(char *file, char *line);
 extern void disown_object_item(char *call_sign,char *new_owner);
 extern void log_object_item(char *line, int disable_object, char *object_name);
 extern void reload_object_item(void);
+extern void log_tactical_call(char *call_sign, char *tactical_call_sign);
+extern void reload_tactical_calls(void);
 extern time_t sec_now(void);
 extern char *get_time(char *time_here);
 
@@ -79,7 +86,7 @@ extern int  valid_path(char *path);
 extern int  valid_call(char *call);
 extern int  valid_object(char *name);
 extern int  valid_item(char *name);
-extern int  valid_inet_name(char *name, char *info, char *origin);
+extern int  valid_inet_name(char *name, char *info, char *origin, int origin_size);
 
 extern char echo_digis[6][9+1];
 extern void upd_echo(char *path);
@@ -90,7 +97,7 @@ extern int  is_num_or_sp(char ch);
 extern int  is_xnum_or_dash(char *data, int max);
 extern void removeCtrlCodes(char *cp);
 extern void makePrintable(char *cp);
-extern void spell_it_out(char *text);
+extern void spell_it_out(char *text, int max_length);
 
 typedef struct
 {
@@ -118,7 +125,7 @@ int curl_getfile(char *fileimg, char *local_filename);
 #endif
 
 extern void split_string( char *data, char *cptr[], int max );
-
+extern int check_unproto_path( char *data );
 
 #endif // __XASTIR_UTIL_H
 
