@@ -1,9 +1,9 @@
 /*
- * $Id: view_message_gui.c,v 1.12 2003/05/20 17:34:11 we7u Exp $
+ * $Id: view_message_gui.c,v 1.23 2004/10/18 18:58:10 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2004  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -51,7 +51,6 @@
 #endif  // TIME_WITH_SYS_TIME
 
 #include "xastir.h"
-#include "db.h"
 #include "main.h"
 #include "util.h"
 
@@ -156,25 +155,54 @@ void all_messages(char from, char *call_sign, char *from_call, char *message) {
 
     if ((vm_range == 0) || ((int)distance_from_my_station(call_sign,temp_my_course) <= vm_range)) {
         if (strlen(message)>95) {
-            strncpy(data1, message, 95);
+            xastir_snprintf(data1,
+                sizeof(data1),
+                "%s",
+                message);
             data1[95]='\0';
-            strncpy(data2, message+95, 95);
+            xastir_snprintf(data2,
+                sizeof(data2),
+                "%s",
+                message+95);
         } else {
-            strcpy(data1, message);
-            strcpy(data2, "");
+            xastir_snprintf(data1,
+                sizeof(data1),
+                "%s",
+                message);
+            data2[0] = '\0';
         }
 
         if (strncmp(call_sign, "java",4) == 0) {
-            strncpy(call_sign, "Broadcast", 9);
-            xastir_snprintf(temp, my_size, "%s %s\n%s\n%s\n", from_call, call_sign,
-                    data1, data2);
+            xastir_snprintf(call_sign,
+                MAX_CALLSIGN+1,
+                "Broadcast");
+            xastir_snprintf(temp,
+                my_size,
+                "%s %s\n%s\n%s\n",
+                from_call,
+                call_sign,
+                data1,
+                data2);
         } else if (strncmp(call_sign, "USER", 4) == 0) {
-            strncpy(call_sign, "Broadcast", 9);
-            xastir_snprintf(temp, my_size, "%s %s\n%s\n%s\n", from_call, call_sign,
-                    data1, data2);
+            xastir_snprintf(call_sign,
+                MAX_CALLSIGN+1,
+                "Broadcast");
+            xastir_snprintf(temp,
+                my_size,
+                "%s %s\n%s\n%s\n",
+                from_call,
+                call_sign,
+                data1,
+                data2);
         } else
-            xastir_snprintf(temp, my_size, "%s to %s via:%c\n%s\n%s\n", from_call,
-                    call_sign, from, data1, data2);
+            xastir_snprintf(temp,
+                my_size,
+                "%s to %s via:%c\n%s\n%s\n",
+                from_call,
+                call_sign,
+                from,
+                data1,
+                data2);
 
         if ((All_messages_dialog != NULL)) {
 
@@ -207,7 +235,13 @@ end_critical_section(&All_messages_dialog_lock, "view_message_gui.c:all_messages
 
 void All_messages_destroy_shell( /*@unused@*/ Widget widget, XtPointer clientData, /*@unused@*/ XtPointer callData) {
     Widget shell = (Widget) clientData;
-    vm_range = atoi(XmTextFieldGetString(vm_dist_data));
+    char *temp_ptr;
+
+
+    temp_ptr = XmTextFieldGetString(vm_dist_data);
+    vm_range = atoi(temp_ptr);
+    XtFree(temp_ptr);
+
     XtPopdown(shell);
 
 begin_critical_section(&All_messages_dialog_lock, "view_message_gui.c:All_messages_destroy_shell" );
@@ -225,8 +259,13 @@ end_critical_section(&All_messages_dialog_lock, "view_message_gui.c:All_messages
 
 void All_messages_change_range( /*@unused@*/ Widget widget, XtPointer clientData, /*@unused@*/ XtPointer callData) {
     Widget shell = (Widget) clientData;
+    char *temp_ptr;
+
+
+    temp_ptr = XmTextFieldGetString(vm_dist_data);
+    vm_range = atoi(temp_ptr);
+    XtFree(temp_ptr);
 
-    vm_range = atoi(XmTextFieldGetString(vm_dist_data));
     XtPopdown(shell);
 
     All_messages_destroy_shell(widget, clientData, callData);
@@ -240,7 +279,9 @@ void All_messages_change_range( /*@unused@*/ Widget widget, XtPointer clientData
 void view_all_messages( /*@unused@*/ Widget w, /*@unused@*/ XtPointer clientData, /*@unused@*/ XtPointer callData) {
     Widget pane, my_form, button_range, button_close, dist, dist_units;
     unsigned int n;
-    Arg args[20];
+#define NCNT 21
+#define IncN(n) if (n< NCNT) n++; else fprintf(stderr, "Oops, too many arguments for array!\a")
+    Arg args[NCNT];
     Atom delw;
     char temp[10];
 
@@ -306,7 +347,7 @@ begin_critical_section(&All_messages_dialog_lock, "view_message_gui.c:view_all_m
                 XmNrightAttachment,XmATTACH_NONE,
                 NULL);
 
-        dist_units = XtVaCreateManagedWidget((units_english_metric?langcode("UNIOP00004"):langcode("UNIOP00005")),
+        dist_units = XtVaCreateManagedWidget((english_units?langcode("UNIOP00004"):langcode("UNIOP00005")),
                 xmLabelWidgetClass, 
                 my_form,
                 XmNtopAttachment, XmATTACH_FORM,
@@ -336,31 +377,48 @@ begin_critical_section(&All_messages_dialog_lock, "view_message_gui.c:view_all_m
                 MY_BACKGROUND_COLOR,
                 NULL);
 
-        n=0;
-        XtSetArg(args[n], XmNrows, 25); n++;
-        XtSetArg(args[n], XmNcolumns, 85); n++;
-        XtSetArg(args[n], XmNeditable, FALSE); n++;
-        XtSetArg(args[n], XmNtraversalOn, TRUE); n++;
-        XtSetArg(args[n], XmNlistSizePolicy, XmVARIABLE); n++;
-        XtSetArg(args[n], XmNeditMode, XmMULTI_LINE_EDIT); n++;
-        XtSetArg(args[n], XmNwordWrap, TRUE); n++;
-        XtSetArg(args[n], XmNscrollHorizontal, TRUE); n++;
-        XtSetArg(args[n], XmNscrollVertical, TRUE); n++;
-//        XtSetArg(args[n], XmNscrollBarDisplayPolicy, XmSTATIC); n++;
-        XtSetArg(args[n], XmNselectionPolicy, XmMULTIPLE_SELECT); n++;
-        XtSetArg(args[n], XmNcursorPositionVisible, FALSE); n++;
-        XtSetArg(args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
-        XtSetArg(args[n], XmNtopWidget, dist); n++;
-        XtSetArg(args[n], XmNtopOffset, 20); n++;
-        XtSetArg(args[n], XmNbottomAttachment, XmATTACH_NONE); n++;
-        XtSetArg(args[n], XmNleftAttachment, XmATTACH_FORM); n++;
-        XtSetArg(args[n], XmNleftOffset, 5); n++;
-        XtSetArg(args[n], XmNrightAttachment, XmATTACH_FORM); n++;
-        XtSetArg(args[n], XmNrightOffset, 5); n++;
-        XtSetArg(args[n], XmNforeground, MY_FG_COLOR); n++;
+        XtAddCallback(button_range, XmNactivateCallback, All_messages_change_range, All_messages_dialog);
 
-// This one causes segfaults, why?
-//        XtSetArg(args[n], XmNbackground, MY_BG_COLOR); n++;
+        button_close = XtVaCreateManagedWidget(langcode("UNIOP00003"),
+                xmPushButtonGadgetClass, 
+                my_form,
+                XmNtopAttachment, XmATTACH_FORM,
+                XmNtopOffset, 5,
+                XmNbottomAttachment, XmATTACH_NONE,
+                XmNleftAttachment, XmATTACH_WIDGET,
+                XmNleftWidget, button_range,
+                XmNleftOffset, 10,
+                XmNrightAttachment, XmATTACH_FORM,
+                XmNnavigationType, XmTAB_GROUP,
+                MY_FOREGROUND_COLOR,
+                MY_BACKGROUND_COLOR,
+                NULL);
+
+        XtAddCallback(button_close, XmNactivateCallback, All_messages_destroy_shell, All_messages_dialog);
+ 
+        n=0;
+        XtSetArg(args[n], XmNrows, 15); IncN(n);
+        XtSetArg(args[n], XmNcolumns, 85); IncN(n);
+        XtSetArg(args[n], XmNeditable, FALSE); IncN(n);
+        XtSetArg(args[n], XmNtraversalOn, TRUE); IncN(n);
+        XtSetArg(args[n], XmNlistSizePolicy, XmVARIABLE); IncN(n);
+        XtSetArg(args[n], XmNeditMode, XmMULTI_LINE_EDIT); IncN(n);
+        XtSetArg(args[n], XmNwordWrap, TRUE); IncN(n);
+        XtSetArg(args[n], XmNscrollHorizontal, TRUE); IncN(n);
+        XtSetArg(args[n], XmNscrollVertical, TRUE); IncN(n);
+//        XtSetArg(args[n], XmNscrollBarDisplayPolicy, XmSTATIC); IncN(n);
+        XtSetArg(args[n], XmNselectionPolicy, XmMULTIPLE_SELECT); IncN(n);
+        XtSetArg(args[n], XmNcursorPositionVisible, FALSE); IncN(n);
+        XtSetArg(args[n], XmNtopAttachment, XmATTACH_WIDGET); IncN(n);
+        XtSetArg(args[n], XmNtopWidget, dist); IncN(n);
+        XtSetArg(args[n], XmNtopOffset, 20); IncN(n);
+        XtSetArg(args[n], XmNbottomAttachment, XmATTACH_FORM); IncN(n);
+        XtSetArg(args[n], XmNleftAttachment, XmATTACH_FORM); IncN(n);
+        XtSetArg(args[n], XmNleftOffset, 5); IncN(n);
+        XtSetArg(args[n], XmNrightAttachment, XmATTACH_FORM); IncN(n);
+        XtSetArg(args[n], XmNrightOffset, 5); IncN(n);
+        XtSetArg(args[n], XmNforeground, MY_FG_COLOR); IncN(n);
+        XtSetArg(args[n], XmNbackground, MY_BG_COLOR); IncN(n);
  
         view_messages_text = XmCreateScrolledText(my_form,
                 "view_all_messages text",
@@ -370,26 +428,6 @@ begin_critical_section(&All_messages_dialog_lock, "view_message_gui.c:view_all_m
 // It's hard to get tab groups working with ScrolledText widgets.  Tab'ing in is
 // fine, but then I'm stuck in insert mode and it absorbs the tabs and beeps.
 
-        button_close = XtVaCreateManagedWidget(langcode("UNIOP00003"),
-                xmPushButtonGadgetClass, 
-                my_form,
-                XmNtopAttachment, XmATTACH_WIDGET,
-                XmNtopWidget, XtParent(view_messages_text),
-                XmNtopOffset, 2,
-                XmNbottomAttachment, XmATTACH_FORM,
-                XmNbottomOffset, 5,
-                XmNleftAttachment, XmATTACH_POSITION,
-                XmNleftPosition, 2,
-                XmNrightAttachment, XmATTACH_POSITION,
-                XmNrightPosition, 3,
-                XmNnavigationType, XmTAB_GROUP,
-                MY_FOREGROUND_COLOR,
-                MY_BACKGROUND_COLOR,
-                NULL);
-
-        XtAddCallback(button_close, XmNactivateCallback, All_messages_destroy_shell, All_messages_dialog);
-        XtAddCallback(button_range, XmNactivateCallback, All_messages_change_range, All_messages_dialog);
-
         pos_dialog(All_messages_dialog);
 
         delw = XmInternAtom(XtDisplay(All_messages_dialog),"WM_DELETE_WINDOW", FALSE);
@@ -398,9 +436,9 @@ begin_critical_section(&All_messages_dialog_lock, "view_message_gui.c:view_all_m
         sprintf(temp,"%d",vm_range);
         XmTextFieldSetString(vm_dist_data,temp);
 
-        XtManageChild(my_form);
         XtManageChild(view_messages_text);
         XtVaSetValues(view_messages_text, XmNbackground, colors[0x0f], NULL);
+        XtManageChild(my_form);
         XtManageChild(pane);
 
         redraw_on_new_packet_data=1;
@@ -411,7 +449,7 @@ begin_critical_section(&All_messages_dialog_lock, "view_message_gui.c:view_all_m
 end_critical_section(&All_messages_dialog_lock, "view_message_gui.c:view_all_messages" );
 
         XtPopup(All_messages_dialog,XtGrabNone);
-        fix_dialog_vsize(All_messages_dialog);
+//        fix_dialog_vsize(All_messages_dialog);
 
         // Move focus to the Close button.  This appears to highlight the
         // button fine, but we're not able to hit the <Enter> key to
