@@ -1,9 +1,9 @@
 /*
- * $Id: wx.h,v 1.4 2003/02/20 09:45:21 we7u Exp $
+ * $Id: wx.h,v 1.7 2004/08/19 06:31:43 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2004  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -53,7 +53,7 @@ extern char wx_station_type[];
 
 
 /* from wx.c */
-extern time_t wx_tx_data1(char *st);
+extern time_t wx_tx_data1(char *st, int st_size);
 extern void wx_decode(unsigned char *wx_line, int port);
 extern void fill_wx_data(void);
 extern void clear_rain_data(void);
@@ -72,6 +72,8 @@ extern void wx_alert_update_list(void);
 
 extern void WX_station(Widget w, XtPointer clientData, XtPointer callData);
 
+extern void wx_alert_finger_output( Widget widget, char *handle);
+
 #endif  // __XASTIR_WX_H
 
 
