@@ -1,9 +1,9 @@
 /*
- * $Id: wx_gui.c,v 1.30 2003/06/06 23:57:17 we7u Exp $
+ * $Id: wx_gui.c,v 1.35 2004/10/18 18:58:10 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2004  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -99,11 +99,11 @@ end_critical_section(&wx_detailed_alert_shell_lock, "wx_gui.c:wx_detailed_alert_
 
 
 
-void wx_alert_double_click_action( Widget widget, XtPointer clientData, XtPointer callData) {
-    char *choice;
-    XmListCallbackStruct *selection = callData;
-    char handle[14];
-    char *ptr;
+// This gets/displays the "finger" output from the WXSVR.  Called
+// from both the Station Info "NWS" button and by double-clicking on
+// the view weather alerts window.
+//
+void wx_alert_finger_output( Widget widget, char *handle) {
     static Widget pane, my_form, mess, button_cancel,wx_detailed_alert_list;
     Atom delw;
     Arg al[20];                     // Arg List
@@ -114,20 +114,6 @@ void wx_alert_double_click_action( Widget widget, XtPointer clientData, XtPointe
     extern FILE *popen(const char *, const char *);
 
 
-    XmStringGetLtoR(selection->item, XmFONTLIST_DEFAULT_TAG, &choice);
-    //fprintf(stderr,"Selected item %d (%s)\n", selection->item_position, choice);
-
-    // Grab the first 13 characters.  Remove spaces.  This is our handle
-    // into the weather server for the full weather alert text.
-
-    strncpy(handle,choice,sizeof(handle));
-    handle[13] = '\0';  // Terminate the string
-    // Remove spaces
-    ptr = handle;
-    while ( (ptr = strpbrk(handle, " ")) )
-        memmove(ptr, ptr+1, strlen(ptr)+1);
-    handle[9] = '\0';   // Terminate after first 9 chars
-
     if (debug_level & 1)
         fprintf(stderr,"Handle: %s\n",handle);
 
@@ -237,7 +223,10 @@ end_critical_section(&wx_detailed_alert_shell_lock, "wx_gui.c:wx_alert_double_cl
     XmListDeleteAllItems(wx_detailed_alert_list);
 
     // Perform a "finger" command in another process
-    xastir_snprintf(temp, sizeof(temp), "/usr/bin/finger %s@wxsvr.net", handle);
+    xastir_snprintf(temp,
+        sizeof(temp),
+        "/usr/bin/finger %s@wxsvr.net",
+        handle);
     if (!(pp = popen (temp, "r"))) {    // Go do the finger command
         perror (temp);  // Print an error message if it failed
         fprintf(stderr,"Weather server didn't answer or 'finger' command couldn't be run\n");
@@ -263,6 +252,42 @@ end_critical_section(&wx_detailed_alert_shell_lock, "wx_gui.c:wx_alert_double_cl
         }
         pclose (pp);
     }
+}
+
+
+
+
+
+void wx_alert_double_click_action( Widget widget, XtPointer clientData, XtPointer callData) {
+    char *choice;
+    XmListCallbackStruct *selection = callData;
+    char handle[14];
+    char *ptr;
+
+
+    XmStringGetLtoR(selection->item, XmFONTLIST_DEFAULT_TAG, &choice);
+    //fprintf(stderr,"Selected item %d (%s)\n", selection->item_position, choice);
+
+    // Grab the first 13 characters.  Remove spaces.  This is our handle
+    // into the weather server for the full weather alert text.
+
+    xastir_snprintf(handle,
+        sizeof(handle),
+        "%s",
+        choice);
+
+    handle[13] = '\0';  // Terminate the string
+    // Remove spaces
+    ptr = handle;
+    while ( (ptr = strpbrk(handle, " ")) )
+        memmove(ptr, ptr+1, strlen(ptr)+1);
+    handle[9] = '\0';   // Terminate after first 9 chars
+
+    if (debug_level & 1)
+        fprintf(stderr,"Handle: %s\n",handle);
+
+    wx_alert_finger_output( widget, handle);
+
     XtFree(choice);
 }
 
@@ -317,31 +342,35 @@ begin_critical_section(&wx_alert_shell_lock, "wx_gui.c:wx_alert_update_list" );
             // TSATOR      NWS-ADVIS   Until: 190315z   OK_C127   TORNDO             H2VAA
             //xastir_snprintf(temp, sizeof(temp), "%-9s   %-9s   Until: %-7s   %-7s   %-20s   %s",
 
-            xastir_snprintf(status, sizeof(status), "   ");
-            xastir_snprintf(temp, sizeof(temp),
-                    "%-9s%s   %-9s   %c%c @%c%c%c%cz ==> %c%c @%c%c%c%cz %s %-7s   %s   %s%s%s%s",
-                    alert_list[nn].from,
-                    alert_list[nn].seq,
-                    alert_list[nn].to,
-                    alert_list[nn].issue_date_time[0],
-                    alert_list[nn].issue_date_time[1],
-                    alert_list[nn].issue_date_time[2],
-                    alert_list[nn].issue_date_time[3],
-                    alert_list[nn].issue_date_time[4],
-                    alert_list[nn].issue_date_time[5],
-                    alert_list[nn].activity[0],
-                    alert_list[nn].activity[1],
-                    alert_list[nn].activity[2],
-                    alert_list[nn].activity[3],
-                    alert_list[nn].activity[4],
-                    alert_list[nn].activity[5],
-                    status,
-                    alert_list[nn].title,
-                    alert_list[nn].alert_tag,
-                    alert_list[nn].desc0,
-                    alert_list[nn].desc1,
-                    alert_list[nn].desc2,
-                    alert_list[nn].desc3);
+            xastir_snprintf(status,
+                sizeof(status),
+                "   ");
+
+            xastir_snprintf(temp,
+                sizeof(temp),
+                "%-9s%s   %-9s   %c%c @%c%c%c%cz ==> %c%c @%c%c%c%cz %s %-7s   %s   %s%s%s%s",
+                alert_list[nn].from,
+                alert_list[nn].seq,
+                alert_list[nn].to,
+                alert_list[nn].issue_date_time[0],
+                alert_list[nn].issue_date_time[1],
+                alert_list[nn].issue_date_time[2],
+                alert_list[nn].issue_date_time[3],
+                alert_list[nn].issue_date_time[4],
+                alert_list[nn].issue_date_time[5],
+                alert_list[nn].activity[0],
+                alert_list[nn].activity[1],
+                alert_list[nn].activity[2],
+                alert_list[nn].activity[3],
+                alert_list[nn].activity[4],
+                alert_list[nn].activity[5],
+                status,
+                alert_list[nn].title,
+                alert_list[nn].alert_tag,
+                alert_list[nn].desc0,
+                alert_list[nn].desc1,
+                alert_list[nn].desc2,
+                alert_list[nn].desc3);
 
 
             item = XmStringCreateLtoR(temp, XmFONTLIST_DEFAULT_TAG);
@@ -1473,9 +1502,11 @@ begin_critical_section(&wx_station_dialog_lock, "wx_gui.c:fill_wx_data" );
 
                 if (weather != 0) {  // we have weather data
                     if (strlen(weather->wx_temp) > 0) {
-                       if (!units_english_metric) {
-                            xastir_snprintf(temp, sizeof(temp), "%03d",
-                                    (int)(((atof(weather->wx_temp)-32)*5.0)/9.0));
+                       if (!english_units) {
+                            xastir_snprintf(temp,
+                                sizeof(temp),
+                                "%03d",
+                                (int)(((atof(weather->wx_temp)-32)*5.0)/9.0));
 
                             XmTextFieldSetString(WX_temp_data,temp);
                         } else XmTextFieldSetString(WX_temp_data,weather->wx_temp);
@@ -1491,9 +1522,11 @@ begin_critical_section(&wx_station_dialog_lock, "wx_gui.c:fill_wx_data" );
                     XtManageChild(WX_wind_cse_data);
 
                     if (strlen(weather->wx_speed) > 0) {
-                        if (!units_english_metric) {
-                            xastir_snprintf(temp, sizeof(temp), "%03d",
-                                    (int)(atof(weather->wx_speed)*1.6094));
+                        if (!english_units) {
+                            xastir_snprintf(temp,
+                                sizeof(temp),
+                                "%03d",
+                                (int)(atof(weather->wx_speed)*1.6094));
 
                             XmTextFieldSetString(WX_wind_spd_data,temp);
                         } else
@@ -1504,9 +1537,11 @@ begin_critical_section(&wx_station_dialog_lock, "wx_gui.c:fill_wx_data" );
                     XtManageChild(WX_wind_spd_data);
 
                     if (strlen(weather->wx_gust) > 0) {
-                        if (!units_english_metric) {
-                            xastir_snprintf(temp, sizeof(temp), "%03d",
-                                    (int)(atof(weather->wx_gust)*1.6094));
+                        if (!english_units) {
+                            xastir_snprintf(temp,
+                                sizeof(temp),
+                                "%03d",
+                                (int)(atof(weather->wx_gust)*1.6094));
 
                             XmTextFieldSetString(WX_wind_gst_data,temp);
                         } else
@@ -1517,12 +1552,16 @@ begin_critical_section(&wx_station_dialog_lock, "wx_gui.c:fill_wx_data" );
                     XtManageChild(WX_wind_gst_data);
 
                     if (strlen(weather->wx_rain_total) > 0) {
-                        if (!units_english_metric)
-                            xastir_snprintf(temp, sizeof(temp), "%0.2f",
-                                    atof(weather->wx_rain_total)*.254);
+                        if (!english_units)
+                            xastir_snprintf(temp,
+                                sizeof(temp),
+                                "%0.2f",
+                                atof(weather->wx_rain_total)*.254);
                         else
-                            xastir_snprintf(temp, sizeof(temp), "%0.2f",
-                                    atof(weather->wx_rain_total)/100.0);
+                            xastir_snprintf(temp,
+                                sizeof(temp),
+                                "%0.2f",
+                                atof(weather->wx_rain_total)/100.0);
 
                         XmTextFieldSetString(WX_rain_data,temp);
                     } else
@@ -1531,12 +1570,16 @@ begin_critical_section(&wx_station_dialog_lock, "wx_gui.c:fill_wx_data" );
                     XtManageChild(WX_rain_data);
 
                     if (strlen(weather->wx_rain) > 0) {
-                        if (!units_english_metric)
-                            xastir_snprintf(temp, sizeof(temp), "%0.2f",
+                        if (!english_units)
+                            xastir_snprintf(temp,
+                                sizeof(temp),
+                                "%0.2f",
                                 atof(weather->wx_rain)*.254);
                         else
-                            xastir_snprintf(temp, sizeof(temp), "%0.2f",
-                                    atof(weather->wx_rain)/100.0);
+                            xastir_snprintf(temp,
+                                sizeof(temp),
+                                "%0.2f",
+                               atof(weather->wx_rain)/100.0);
 
                         XmTextFieldSetString(WX_rain_h_data,temp);
                     } else
@@ -1545,12 +1588,16 @@ begin_critical_section(&wx_station_dialog_lock, "wx_gui.c:fill_wx_data" );
                     XtManageChild(WX_rain_h_data);
 
                     if (strlen(weather->wx_prec_24) > 0) {
-                        if (!units_english_metric)
-                            xastir_snprintf(temp, sizeof(temp), "%0.2f",
-                                    atof(weather->wx_prec_24)*.254);
+                        if (!english_units)
+                            xastir_snprintf(temp,
+                                sizeof(temp),
+                                "%0.2f",
+                                atof(weather->wx_prec_24)*.254);
                         else
-                            xastir_snprintf(temp, sizeof(temp), "%0.2f",
-                                    atof(weather->wx_prec_24)/100.0);
+                            xastir_snprintf(temp,
+                                sizeof(temp),
+                                "%0.2f",
+                                atof(weather->wx_prec_24)/100.0);
 
                         XmTextFieldSetString(WX_rain_24_data,temp);
                     } else
@@ -1559,12 +1606,16 @@ begin_critical_section(&wx_station_dialog_lock, "wx_gui.c:fill_wx_data" );
                     XtManageChild(WX_rain_24_data);
 
                     if (strlen(weather->wx_prec_00) > 0) {
-                        if (!units_english_metric)
-                            xastir_snprintf(temp, sizeof(temp), "%0.2f",
-                                    atof(weather->wx_prec_00)*.254);
+                        if (!english_units)
+                            xastir_snprintf(temp,
+                                sizeof(temp),
+                                "%0.2f",
+                                atof(weather->wx_prec_00)*.254);
                         else
-                            xastir_snprintf(temp, sizeof(temp), "%0.2f",
-                                    atof(weather->wx_prec_00)/100.0);
+                            xastir_snprintf(temp,
+                                sizeof(temp),
+                                "%0.2f",
+                                atof(weather->wx_prec_00)/100.0);
 
                         XmTextFieldSetString(WX_to_rain_data,temp);
                     } else
@@ -1580,9 +1631,11 @@ begin_critical_section(&wx_station_dialog_lock, "wx_gui.c:fill_wx_data" );
                     XtManageChild(WX_humidity_data);
 
                     if (strlen(wx_dew_point) > 0) {
-                        if (!units_english_metric) {
-                            xastir_snprintf(temp, sizeof(temp), "%03d",
-                                    (int)(((atof(wx_dew_point)-32)*5.0)/9.0));
+                        if (!english_units) {
+                            xastir_snprintf(temp,
+                                sizeof(temp),
+                                "%03d",
+                                (int)(((atof(wx_dew_point)-32)*5.0)/9.0));
                             XmTextFieldSetString(WX_dew_point_data,temp);
                         } else
                             XmTextFieldSetString(WX_dew_point_data,wx_dew_point);
@@ -1592,9 +1645,11 @@ begin_critical_section(&wx_station_dialog_lock, "wx_gui.c:fill_wx_data" );
                     XtManageChild(WX_dew_point_data);
 
                     if (strlen(wx_high_wind) > 0) {
-                        if (!units_english_metric) {
-                            xastir_snprintf(temp, sizeof(temp), "%03d",
-                                    (int)(atof(wx_high_wind)*1.6094));
+                        if (!english_units) {
+                            xastir_snprintf(temp,
+                                sizeof(temp),
+                                "%03d",
+                                (int)(atof(wx_high_wind)*1.6094));
                             XmTextFieldSetString(WX_high_wind_data,temp);
                         } else
                             XmTextFieldSetString(WX_high_wind_data,wx_high_wind);
@@ -1604,9 +1659,11 @@ begin_critical_section(&wx_station_dialog_lock, "wx_gui.c:fill_wx_data" );
                     XtManageChild(WX_high_wind_data);
 
                     if (strlen(wx_wind_chill) > 0) {
-                        if (!units_english_metric) {
-                            xastir_snprintf(temp, sizeof(temp), "%03d",
-                                    (int)(((atof(wx_wind_chill)-32)*5.0)/9.0));
+                        if (!english_units) {
+                            xastir_snprintf(temp,
+                                sizeof(temp),
+                                "%03d",
+                                (int)(((atof(wx_wind_chill)-32)*5.0)/9.0));
                             XmTextFieldSetString(WX_wind_chill_data,temp);
                         } else
                             XmTextFieldSetString(WX_wind_chill_data,wx_wind_chill);
@@ -1616,14 +1673,16 @@ begin_critical_section(&wx_station_dialog_lock, "wx_gui.c:fill_wx_data" );
                     XtManageChild(WX_wind_chill_data);
 
                     if (strlen(weather->wx_baro) > 0) {
-                        if (!units_english_metric) {
+                        if (!english_units) {
                             //xastir_snprintf(temp, sizeof(temp), "%0.0f",
                             //        atof(wx_baro_inHg)*25.4); // inch Hg -> mm Hg
                             //XmTextFieldSetString(WX_baro_data,temp);
                             XmTextFieldSetString(WX_baro_data,weather->wx_baro); // hPa
                         }
                         else {  // inches mercury
-                            xastir_snprintf(temp, sizeof(temp), "%0.2f",
+                            xastir_snprintf(temp,
+                                sizeof(temp),
+                                "%0.2f",
                                 (atof(weather->wx_baro)*0.02953));
                             XmTextFieldSetString(WX_baro_data,temp);
                         }
@@ -1633,12 +1692,14 @@ begin_critical_section(&wx_station_dialog_lock, "wx_gui.c:fill_wx_data" );
                     XtManageChild(WX_baro_data);
 
                     if (wx_three_hour_baro_on) {
-                        if (!units_english_metric) {  // hPa
+                        if (!english_units) {  // hPa
                             //xastir_snprintf(temp, sizeof(temp), "%0.0f",
                             //        atof(wx_three_hour_baro)*25.4); // inch Hg -> mm Hg
                             XmTextFieldSetString(WX_three_hour_baro_data,wx_three_hour_baro);
                         } else {  // inches mercury
-                            xastir_snprintf(temp, sizeof(temp), "%0.2f",
+                            xastir_snprintf(temp,
+                                sizeof(temp),
+                                "%0.2f",
                                 (atof(wx_three_hour_baro)*0.02953));
                             XmTextFieldSetString(WX_three_hour_baro_data,temp);
                         }
@@ -1648,9 +1709,11 @@ begin_critical_section(&wx_station_dialog_lock, "wx_gui.c:fill_wx_data" );
                     XtManageChild(WX_three_hour_baro_data);
 
                     if (wx_hi_temp_on) {
-                        if (!units_english_metric) {
-                            xastir_snprintf(temp, sizeof(temp), "%03d",
-                                    (int)(((atof(wx_hi_temp)-32)*5.0)/9.0));
+                        if (!english_units) {
+                            xastir_snprintf(temp,
+                                sizeof(temp),
+                                "%03d",
+                                (int)(((atof(wx_hi_temp)-32)*5.0)/9.0));
                             XmTextFieldSetString(WX_hi_temp_data,temp);
                         } else
                             XmTextFieldSetString(WX_hi_temp_data,wx_hi_temp);
@@ -1660,9 +1723,11 @@ begin_critical_section(&wx_station_dialog_lock, "wx_gui.c:fill_wx_data" );
                     XtManageChild(WX_hi_temp_data);
 
                     if (wx_low_temp_on) {
-                        if (!units_english_metric) {
-                            xastir_snprintf(temp, sizeof(temp), "%03d",
-                                    (int)(((atof(wx_low_temp)-32)*5.0)/9.0));
+                        if (!english_units) {
+                            xastir_snprintf(temp,
+                                sizeof(temp),
+                                "%03d",
+                                (int)(((atof(wx_low_temp)-32)*5.0)/9.0));
                             XmTextFieldSetString(WX_low_temp_data,temp);
                         } else
                             XmTextFieldSetString(WX_low_temp_data,wx_low_temp);
@@ -1672,9 +1737,11 @@ begin_critical_section(&wx_station_dialog_lock, "wx_gui.c:fill_wx_data" );
                     XtManageChild(WX_low_temp_data);
 
                     if (wx_heat_index_on) {
-                        if (!units_english_metric) {
-                            xastir_snprintf(temp, sizeof(temp), "%03d",
-                                    (int)(((atof(wx_heat_index)-32)*5.0)/9.0));
+                        if (!english_units) {
+                            xastir_snprintf(temp,
+                                sizeof(temp),
+                                "%03d",
+                                (int)(((atof(wx_heat_index)-32)*5.0)/9.0));
                             XmTextFieldSetString(WX_heat_index_data,temp);
                         } else
                             XmTextFieldSetString(WX_heat_index_data,wx_heat_index);
@@ -1687,105 +1754,105 @@ begin_critical_section(&wx_station_dialog_lock, "wx_gui.c:fill_wx_data" );
         }
 
         /* labels */
-        if (!units_english_metric)
+        if (!english_units)
             XmTextFieldSetString(WX_speed_label,langcode("UNIOP00012"));
         else
             XmTextFieldSetString(WX_speed_label,langcode("UNIOP00013"));
 
         XtManageChild(WX_speed_label);
 
-        if (!units_english_metric)
+        if (!english_units)
             XmTextFieldSetString(WX_gust_label,langcode("UNIOP00012"));
         else
             XmTextFieldSetString(WX_gust_label,langcode("UNIOP00013"));
 
         XtManageChild(WX_gust_label);
 
-        if (!units_english_metric)
+        if (!english_units)
             XmTextFieldSetString(WX_temp_label,langcode("UNIOP00014"));
         else
             XmTextFieldSetString(WX_temp_label,langcode("UNIOP00015"));
 
         XtManageChild(WX_temp_label);
 
-        if (!units_english_metric)
+        if (!english_units)
             XmTextFieldSetString(WX_rain_label,langcode("UNIOP00016"));
         else
             XmTextFieldSetString(WX_rain_label,langcode("UNIOP00017"));
 
         XtManageChild(WX_rain_label);
 
-        if (!units_english_metric)
+        if (!english_units)
             XmTextFieldSetString(WX_to_rain_label,langcode("UNIOP00022"));
         else
             XmTextFieldSetString(WX_to_rain_label,langcode("UNIOP00023"));
 
         XtManageChild(WX_to_rain_label);
 
-        if (!units_english_metric)
+        if (!english_units)
             XmTextFieldSetString(WX_rain_h_label,langcode("UNIOP00020"));
         else
             XmTextFieldSetString(WX_rain_h_label,langcode("UNIOP00021"));
 
         XtManageChild(WX_rain_h_label);
 
-        if (!units_english_metric)
+        if (!english_units)
             XmTextFieldSetString(WX_rain_24_label,langcode("UNIOP00018"));
         else
             XmTextFieldSetString(WX_rain_24_label,langcode("UNIOP00019"));
 
         XtManageChild(WX_rain_24_label);
 
-        if (!units_english_metric)
+        if (!english_units)
             XmTextFieldSetString(WX_dew_point_label,langcode("UNIOP00014"));
         else
             XmTextFieldSetString(WX_dew_point_label,langcode("UNIOP00015"));
 
         XtManageChild(WX_dew_point_label);
 
-        if (!units_english_metric)
+        if (!english_units)
             XmTextFieldSetString(WX_wind_chill_label,langcode("UNIOP00014"));
         else
             XmTextFieldSetString(WX_wind_chill_label,langcode("UNIOP00015"));
 
         XtManageChild(WX_wind_chill_label);
 
-        if (!units_english_metric)
+        if (!english_units)
             XmTextFieldSetString(WX_heat_index_label,langcode("UNIOP00014"));
         else
             XmTextFieldSetString(WX_heat_index_label,langcode("UNIOP00015"));
 
         XtManageChild(WX_heat_index_label);
 
-        if (!units_english_metric)
+        if (!english_units)
             XmTextFieldSetString(WX_hi_temp_label,langcode("UNIOP00014"));
         else
             XmTextFieldSetString(WX_hi_temp_label,langcode("UNIOP00015"));
 
         XtManageChild(WX_hi_temp_label);
 
-        if (!units_english_metric)
+        if (!english_units)
             XmTextFieldSetString(WX_low_temp_label,langcode("UNIOP00014"));
         else
             XmTextFieldSetString(WX_low_temp_label,langcode("UNIOP00015"));
 
         XtManageChild(WX_low_temp_label);
 
-        if (!units_english_metric)
+        if (!english_units)
             XmTextFieldSetString(WX_high_wind_label,langcode("UNIOP00012"));
         else
             XmTextFieldSetString(WX_high_wind_label,langcode("UNIOP00013"));
 
         XtManageChild(WX_high_wind_label);
 
-        if (!units_english_metric)
+        if (!english_units)
             XmTextFieldSetString(WX_baro_label,langcode("UNIOP00025"));
         else
             XmTextFieldSetString(WX_baro_label,langcode("UNIOP00027"));
 
         XtManageChild(WX_baro_label);
 
-        if (!units_english_metric)
+        if (!english_units)
             XmTextFieldSetString(WX_three_hour_baro_label,langcode("UNIOP00025"));
         else
             XmTextFieldSetString(WX_three_hour_baro_label,langcode("UNIOP00027"));
