@@ -1,9 +1,9 @@
-/* -*- c-basic-indent: 4; indent-tabs-mode: nil -*-
- * $Id: xastir.h,v 1.24 2003/04/01 17:55:51 we7u Exp $
+/* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
+ * $Id: xastir.h,v 1.40 2004/10/02 18:08:20 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2004  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,6 +28,62 @@
 #define _XASTIR_H
 
 
+// If libgc is installed, uncomment this next line to enable memory
+// leak detection:
+#define DETECT_MEMORY_LEAKS
+
+
+// Defines for including the libgc garbage collection library.
+// This enables automatic garbage collection of unused memory,
+// very similar to the garbage collection in Java.  Get libgc from
+// here:  http://www.hpl.hp.com/personal/Hans_Boehm/gc/
+//
+// This will cause stats to be printed every 60 seconds, 'cuz we
+// call GC_collect via a macro from UpdateTime() once per minute:
+// export GC_PRINT_STATS=1; xastir &
+//
+// Compile libgc with this option for more debugging output.  I
+// didn't do so:  --enable-full_debug 
+//
+// If we enable these thread options, Xastir won't link with the
+// library.  Since we don't allocate dynamic memory in the child
+// threads anyway, skip them.
+// --enable-threads=posix --enable-thread-local-alloc --enable-parallel-mark
+//
+// Call GC_gcollect at appropriate points to check for leaks.  We do
+// this via the CHECK_LEAKS macro called from main.c:UpdateTime.
+//
+#ifdef HAVE_GC_H
+  #ifdef HAVE_LIBGC
+
+    // We use this define to enable code in *.c files
+    #define USING_LIBGC
+
+    // Set up for threads
+//    #define GC_THREADS
+
+    // Ask for more debugging
+    #define GC_DEBUG
+
+    #include <malloc.h>
+    #include <gc.h>
+    #define malloc(n) GC_MALLOC(n)
+    #define calloc(m,n) GC_MALLOC((m)*(n))
+    #define free(p) GC_FREE(p)
+    #define realloc(p,n) GC_REALLOC((p),(n))
+    #define CHECK_LEAKS() GC_gcollect()
+
+  #endif    // HAVE_LIBGC
+#endif  // HAVE_GC_H
+ 
+
+
+// Macros that help us avoid warnings on 64-bit CPU's.
+// Borrowed from the freeciv project (also a GPL project).
+#define INT_TO_XTPOINTER(m_i)  ((XtPointer)((long)(m_i)))
+#define XTPOINTER_TO_INT(m_p)  ((int)((long)(m_p)))
+
+
 #define SERIAL_KISS_RELAY_DIGI
 
 
@@ -40,6 +96,9 @@
 #include "rac_data.h"
 
 
+#define MAX_CALLSIGN 9       // Objects are up to 9 chars
+
+
 // black
 #define MY_FG_COLOR             colors[0x08]
 #define MY_FOREGROUND_COLOR     XmNforeground,colors[0x08]
@@ -55,12 +114,14 @@
 #define CONVERT_DEC_DEG         4
 #define CONVERT_UP_TRK          5
 #define CONVERT_DMS_NORMAL      6
+#define CONVERT_VHP_NOSP        7
 
 #ifndef M_PI                      /* if not defined in math.h */
 #define M_PI 3.14159265358979323846
 #endif  // M_PI
 
 /* GLOBAL DEFINES */
+extern char dangerous_operation[200];
 extern GC gc;
 extern Pixmap  pixmap;
 extern Pixmap  pixmap_final;
@@ -106,6 +167,8 @@ extern long x_long_offset;
 extern long y_lat_offset;
 extern long scale_x;            // x scaling in 1/100 sec per pixel
 extern long scale_y;            // y scaling in 1/100 sec per pixel
+extern float f_center_latitude;
+extern float f_center_longitude;
 extern long screen_width;
 extern long screen_height;
 extern int long_lat_grid;
@@ -124,6 +187,15 @@ extern int redraw_on_new_data;
 //extern Widget hidden_shell;
 extern int tiger_flag;
 extern int index_maps_on_startup;
+#define MAX_LABEL_FONTNAME 256
+#define FONT_TINY 0
+#define FONT_SMALL 1
+#define FONT_MEDIUM 2
+#define FONT_LARGE 3
+#define FONT_HUGE 4
+#define FONT_MAX 5
+#define FONT_DEFAULT FONT_MEDIUM
+extern char rotated_label_fontname[FONT_MAX][MAX_LABEL_FONTNAME];
 
 #ifdef HAVE_IMAGEMAGICK  //N0VH
 extern int tiger_show_grid;
@@ -140,7 +212,6 @@ extern int tiger_show_statehwy;
 extern int tiger_show_water;
 extern int tiger_show_lakes;
 extern int tiger_show_misc;
-extern int tigermap_intensity;
 extern int tigermap_timeout;
 #endif  // HAVE_IMAGEMAGICK
 
@@ -206,6 +277,7 @@ extern int gps_port_save;
 extern double calc_dscale_x(long x, long y);
 
 /* from popup_gui.c */
+extern void popup_message_always(char *banner, char *message);
 extern void popup_message(char *banner, char *message);
 extern void popup_ID_message(char *banner, char *message);
 
